# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class TextReplace(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'old_value': 'str',
        'new_value': 'str',
        'regex': 'bool',
        'text_state': 'TextState',
        'rect': 'Rectangle',
        'center_text_horizontally': 'bool'
    }

    attribute_map = {
        'old_value': 'OldValue',
        'new_value': 'NewValue',
        'regex': 'Regex',
        'text_state': 'TextState',
        'rect': 'Rect',
        'center_text_horizontally': 'CenterTextHorizontally'
    }

    def __init__(self, old_value=None, new_value=None, regex=None, text_state=None, rect=None, center_text_horizontally=None):
        """
        TextReplace - a model defined in Swagger
        """

        self._old_value = None
        self._new_value = None
        self._regex = None
        self._text_state = None
        self._rect = None
        self._center_text_horizontally = None

        self.old_value = old_value
        if new_value is not None:
          self.new_value = new_value
        self.regex = regex
        if text_state is not None:
          self.text_state = text_state
        if rect is not None:
          self.rect = rect
        if center_text_horizontally is not None:
          self.center_text_horizontally = center_text_horizontally

    @property
    def old_value(self):
        """
        Gets the old_value of this TextReplace.
        Original text.

        :return: The old_value of this TextReplace.
        :rtype: str
        """
        return self._old_value

    @old_value.setter
    def old_value(self, old_value):
        """
        Sets the old_value of this TextReplace.
        Original text.

        :param old_value: The old_value of this TextReplace.
        :type: str
        """
        if old_value is None:
            raise ValueError("Invalid value for `old_value`, must not be `None`")
        if old_value is not None and len(old_value) < 1:
            raise ValueError("Invalid value for `old_value`, length must be greater than or equal to `1`")

        self._old_value = old_value

    @property
    def new_value(self):
        """
        Gets the new_value of this TextReplace.
        New text.

        :return: The new_value of this TextReplace.
        :rtype: str
        """
        return self._new_value

    @new_value.setter
    def new_value(self, new_value):
        """
        Sets the new_value of this TextReplace.
        New text.

        :param new_value: The new_value of this TextReplace.
        :type: str
        """

        self._new_value = new_value

    @property
    def regex(self):
        """
        Gets the regex of this TextReplace.
        Gets or sets a value indicating whether search text is regular expression.

        :return: The regex of this TextReplace.
        :rtype: bool
        """
        return self._regex

    @regex.setter
    def regex(self, regex):
        """
        Sets the regex of this TextReplace.
        Gets or sets a value indicating whether search text is regular expression.

        :param regex: The regex of this TextReplace.
        :type: bool
        """
        if regex is None:
            raise ValueError("Invalid value for `regex`, must not be `None`")

        self._regex = regex

    @property
    def text_state(self):
        """
        Gets the text_state of this TextReplace.
        Text properties of a new text.

        :return: The text_state of this TextReplace.
        :rtype: TextState
        """
        return self._text_state

    @text_state.setter
    def text_state(self, text_state):
        """
        Sets the text_state of this TextReplace.
        Text properties of a new text.

        :param text_state: The text_state of this TextReplace.
        :type: TextState
        """

        self._text_state = text_state

    @property
    def rect(self):
        """
        Gets the rect of this TextReplace.
        Rectangle area where searched original text.

        :return: The rect of this TextReplace.
        :rtype: Rectangle
        """
        return self._rect

    @rect.setter
    def rect(self, rect):
        """
        Sets the rect of this TextReplace.
        Rectangle area where searched original text.

        :param rect: The rect of this TextReplace.
        :type: Rectangle
        """

        self._rect = rect

    @property
    def center_text_horizontally(self):
        """
        Gets the center_text_horizontally of this TextReplace.
        The text after replacement is centered horizontally relative to the text being replaced.

        :return: The center_text_horizontally of this TextReplace.
        :rtype: bool
        """
        return self._center_text_horizontally

    @center_text_horizontally.setter
    def center_text_horizontally(self, center_text_horizontally):
        """
        Sets the center_text_horizontally of this TextReplace.
        The text after replacement is centered horizontally relative to the text being replaced.

        :param center_text_horizontally: The center_text_horizontally of this TextReplace.
        :type: bool
        """

        self._center_text_horizontally = center_text_horizontally

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TextReplace):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class TextState(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'font_size': 'float',
        'font': 'str',
        'foreground_color': 'Color',
        'background_color': 'Color',
        'font_style': 'FontStyles',
        'font_file': 'str',
        'underline': 'bool',
        'strike_out': 'bool',
        'superscript': 'bool',
        'subscript': 'bool'
    }

    attribute_map = {
        'font_size': 'FontSize',
        'font': 'Font',
        'foreground_color': 'ForegroundColor',
        'background_color': 'BackgroundColor',
        'font_style': 'FontStyle',
        'font_file': 'FontFile',
        'underline': 'Underline',
        'strike_out': 'StrikeOut',
        'superscript': 'Superscript',
        'subscript': 'Subscript'
    }

    def __init__(self, font_size=None, font=None, foreground_color=None, background_color=None, font_style=None, font_file=None, underline=None, strike_out=None, superscript=None, subscript=None):
        """
        TextState - a model defined in Swagger
        """

        self._font_size = None
        self._font = None
        self._foreground_color = None
        self._background_color = None
        self._font_style = None
        self._font_file = None
        self._underline = None
        self._strike_out = None
        self._superscript = None
        self._subscript = None

        self.font_size = font_size
        if font is not None:
          self.font = font
        if foreground_color is not None:
          self.foreground_color = foreground_color
        if background_color is not None:
          self.background_color = background_color
        self.font_style = font_style
        if font_file is not None:
          self.font_file = font_file
        if underline is not None:
          self.underline = underline
        if strike_out is not None:
          self.strike_out = strike_out
        if superscript is not None:
          self.superscript = superscript
        if subscript is not None:
          self.subscript = subscript

    @property
    def font_size(self):
        """
        Gets the font_size of this TextState.
        Gets or sets font size of the text.

        :return: The font_size of this TextState.
        :rtype: float
        """
        return self._font_size

    @font_size.setter
    def font_size(self, font_size):
        """
        Sets the font_size of this TextState.
        Gets or sets font size of the text.

        :param font_size: The font_size of this TextState.
        :type: float
        """
        if font_size is None:
            raise ValueError("Invalid value for `font_size`, must not be `None`")

        self._font_size = font_size

    @property
    def font(self):
        """
        Gets the font of this TextState.
        Gets or sets font name of the text.

        :return: The font of this TextState.
        :rtype: str
        """
        return self._font

    @font.setter
    def font(self, font):
        """
        Sets the font of this TextState.
        Gets or sets font name of the text.

        :param font: The font of this TextState.
        :type: str
        """

        self._font = font

    @property
    def foreground_color(self):
        """
        Gets the foreground_color of this TextState.
        Gets or sets foreground color of the text.

        :return: The foreground_color of this TextState.
        :rtype: Color
        """
        return self._foreground_color

    @foreground_color.setter
    def foreground_color(self, foreground_color):
        """
        Sets the foreground_color of this TextState.
        Gets or sets foreground color of the text.

        :param foreground_color: The foreground_color of this TextState.
        :type: Color
        """

        self._foreground_color = foreground_color

    @property
    def background_color(self):
        """
        Gets the background_color of this TextState.
        Sets background color of the text.

        :return: The background_color of this TextState.
        :rtype: Color
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color of this TextState.
        Sets background color of the text.

        :param background_color: The background_color of this TextState.
        :type: Color
        """

        self._background_color = background_color

    @property
    def font_style(self):
        """
        Gets the font_style of this TextState.
        Sets font style of the text.

        :return: The font_style of this TextState.
        :rtype: FontStyles
        """
        return self._font_style

    @font_style.setter
    def font_style(self, font_style):
        """
        Sets the font_style of this TextState.
        Sets font style of the text.

        :param font_style: The font_style of this TextState.
        :type: FontStyles
        """
        if font_style is None:
            raise ValueError("Invalid value for `font_style`, must not be `None`")

        self._font_style = font_style

    @property
    def font_file(self):
        """
        Gets the font_file of this TextState.
        Sets path of font file in storage.

        :return: The font_file of this TextState.
        :rtype: str
        """
        return self._font_file

    @font_file.setter
    def font_file(self, font_file):
        """
        Sets the font_file of this TextState.
        Sets path of font file in storage.

        :param font_file: The font_file of this TextState.
        :type: str
        """

        self._font_file = font_file

    @property
    def underline(self):
        """
        Gets the underline of this TextState.
        Gets or sets underline of the text.

        :return: The underline of this TextState.
        :rtype: bool
        """
        return self._underline

    @underline.setter
    def underline(self, underline):
        """
        Sets the underline of this TextState.
        Gets or sets underline of the text.

        :param underline: The underline of this TextState.
        :type: bool
        """

        self._underline = underline

    @property
    def strike_out(self):
        """
        Gets the strike_out of this TextState.
        Gets or sets strikeout of the text.

        :return: The strike_out of this TextState.
        :rtype: bool
        """
        return self._strike_out

    @strike_out.setter
    def strike_out(self, strike_out):
        """
        Sets the strike_out of this TextState.
        Gets or sets strikeout of the text.

        :param strike_out: The strike_out of this TextState.
        :type: bool
        """

        self._strike_out = strike_out

    @property
    def superscript(self):
        """
        Gets the superscript of this TextState.
        Gets or sets superscript mode of the text.

        :return: The superscript of this TextState.
        :rtype: bool
        """
        return self._superscript

    @superscript.setter
    def superscript(self, superscript):
        """
        Sets the superscript of this TextState.
        Gets or sets superscript mode of the text.

        :param superscript: The superscript of this TextState.
        :type: bool
        """

        self._superscript = superscript

    @property
    def subscript(self):
        """
        Gets the subscript of this TextState.
        Gets or sets subscript mode of the text.

        :return: The subscript of this TextState.
        :rtype: bool
        """
        return self._subscript

    @subscript.setter
    def subscript(self, subscript):
        """
        Sets the subscript of this TextState.
        Gets or sets subscript mode of the text.

        :param subscript: The subscript of this TextState.
        :type: bool
        """

        self._subscript = subscript

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TextState):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *

file_name = 'PdfWithScreenAnnotations.pdf'
uploadFile(file_name)

page_number = 1

response = pdf_api.get_page_screen_annotations(
    file_name, page_number, folder=temp_folder)

pprint(response)


from configuration import *
file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

parent_id = 'GI5TCMR3GE2TQLBSGM3CYMJYGUWDENRV'

annotation = asposepdfcloud.models.PopupAnnotation()
annotation.name = 'Name'
annotation.rect = asposepdfcloud.models.Rectangle(
    llx=100, lly=100, urx=200, ury=200)
annotation.flags = [asposepdfcloud.models.AnnotationFlags.DEFAULT]
annotation.horizontal_alignment = asposepdfcloud.models.HorizontalAlignment.CENTER
annotation.z_index = 1
annotation.modified = '02/02/2018 00:00:00.000 AM'

response = pdf_api.post_popup_annotation(
    file_name, parent_id, annotation, folder=temp_folder)

pprint(response)



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class SignatureField(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[Link]',
        'partial_name': 'str',
        'full_name': 'str',
        'rect': 'Rectangle',
        'value': 'str',
        'page_index': 'int',
        'height': 'float',
        'width': 'float',
        'z_index': 'int',
        'is_group': 'bool',
        'parent': 'FormField',
        'is_shared_field': 'bool',
        'flags': 'list[AnnotationFlags]',
        'color': 'Color',
        'contents': 'str',
        'margin': 'MarginInfo',
        'highlighting': 'LinkHighlightingMode',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'border': 'Border',
        'signature': 'Signature'
    }

    attribute_map = {
        'links': 'Links',
        'partial_name': 'PartialName',
        'full_name': 'FullName',
        'rect': 'Rect',
        'value': 'Value',
        'page_index': 'PageIndex',
        'height': 'Height',
        'width': 'Width',
        'z_index': 'ZIndex',
        'is_group': 'IsGroup',
        'parent': 'Parent',
        'is_shared_field': 'IsSharedField',
        'flags': 'Flags',
        'color': 'Color',
        'contents': 'Contents',
        'margin': 'Margin',
        'highlighting': 'Highlighting',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'border': 'Border',
        'signature': 'Signature'
    }

    def __init__(self, links=None, partial_name=None, full_name=None, rect=None, value=None, page_index=None, height=None, width=None, z_index=None, is_group=None, parent=None, is_shared_field=None, flags=None, color=None, contents=None, margin=None, highlighting=None, horizontal_alignment=None, vertical_alignment=None, border=None, signature=None):
        """
        SignatureField - a model defined in Swagger
        """

        self._links = None
        self._partial_name = None
        self._full_name = None
        self._rect = None
        self._value = None
        self._page_index = None
        self._height = None
        self._width = None
        self._z_index = None
        self._is_group = None
        self._parent = None
        self._is_shared_field = None
        self._flags = None
        self._color = None
        self._contents = None
        self._margin = None
        self._highlighting = None
        self._horizontal_alignment = None
        self._vertical_alignment = None
        self._border = None
        self._signature = None

        if links is not None:
          self.links = links
        if partial_name is not None:
          self.partial_name = partial_name
        if full_name is not None:
          self.full_name = full_name
        if rect is not None:
          self.rect = rect
        if value is not None:
          self.value = value
        self.page_index = page_index
        if height is not None:
          self.height = height
        if width is not None:
          self.width = width
        if z_index is not None:
          self.z_index = z_index
        if is_group is not None:
          self.is_group = is_group
        if parent is not None:
          self.parent = parent
        if is_shared_field is not None:
          self.is_shared_field = is_shared_field
        if flags is not None:
          self.flags = flags
        if color is not None:
          self.color = color
        if contents is not None:
          self.contents = contents
        if margin is not None:
          self.margin = margin
        if highlighting is not None:
          self.highlighting = highlighting
        if horizontal_alignment is not None:
          self.horizontal_alignment = horizontal_alignment
        if vertical_alignment is not None:
          self.vertical_alignment = vertical_alignment
        if border is not None:
          self.border = border
        if signature is not None:
          self.signature = signature

    @property
    def links(self):
        """
        Gets the links of this SignatureField.
        Link to the document.

        :return: The links of this SignatureField.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this SignatureField.
        Link to the document.

        :param links: The links of this SignatureField.
        :type: list[Link]
        """

        self._links = links

    @property
    def partial_name(self):
        """
        Gets the partial_name of this SignatureField.
        Field name.

        :return: The partial_name of this SignatureField.
        :rtype: str
        """
        return self._partial_name

    @partial_name.setter
    def partial_name(self, partial_name):
        """
        Sets the partial_name of this SignatureField.
        Field name.

        :param partial_name: The partial_name of this SignatureField.
        :type: str
        """

        self._partial_name = partial_name

    @property
    def full_name(self):
        """
        Gets the full_name of this SignatureField.
        Full Field name.

        :return: The full_name of this SignatureField.
        :rtype: str
        """
        return self._full_name

    @full_name.setter
    def full_name(self, full_name):
        """
        Sets the full_name of this SignatureField.
        Full Field name.

        :param full_name: The full_name of this SignatureField.
        :type: str
        """

        self._full_name = full_name

    @property
    def rect(self):
        """
        Gets the rect of this SignatureField.
        Field rectangle.

        :return: The rect of this SignatureField.
        :rtype: Rectangle
        """
        return self._rect

    @rect.setter
    def rect(self, rect):
        """
        Sets the rect of this SignatureField.
        Field rectangle.

        :param rect: The rect of this SignatureField.
        :type: Rectangle
        """

        self._rect = rect

    @property
    def value(self):
        """
        Gets the value of this SignatureField.
        Field value.

        :return: The value of this SignatureField.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this SignatureField.
        Field value.

        :param value: The value of this SignatureField.
        :type: str
        """

        self._value = value

    @property
    def page_index(self):
        """
        Gets the page_index of this SignatureField.
        Page index.

        :return: The page_index of this SignatureField.
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """
        Sets the page_index of this SignatureField.
        Page index.

        :param page_index: The page_index of this SignatureField.
        :type: int
        """
        if page_index is None:
            raise ValueError("Invalid value for `page_index`, must not be `None`")

        self._page_index = page_index

    @property
    def height(self):
        """
        Gets the height of this SignatureField.
        Gets or sets height of the field.

        :return: The height of this SignatureField.
        :rtype: float
        """
        return self._height

    @height.setter
    def height(self, height):
        """
        Sets the height of this SignatureField.
        Gets or sets height of the field.

        :param height: The height of this SignatureField.
        :type: float
        """

        self._height = height

    @property
    def width(self):
        """
        Gets the width of this SignatureField.
        Gets or sets width of the field.

        :return: The width of this SignatureField.
        :rtype: float
        """
        return self._width

    @width.setter
    def width(self, width):
        """
        Sets the width of this SignatureField.
        Gets or sets width of the field.

        :param width: The width of this SignatureField.
        :type: float
        """

        self._width = width

    @property
    def z_index(self):
        """
        Gets the z_index of this SignatureField.
        Z index.

        :return: The z_index of this SignatureField.
        :rtype: int
        """
        return self._z_index

    @z_index.setter
    def z_index(self, z_index):
        """
        Sets the z_index of this SignatureField.
        Z index.

        :param z_index: The z_index of this SignatureField.
        :type: int
        """

        self._z_index = z_index

    @property
    def is_group(self):
        """
        Gets the is_group of this SignatureField.
        Is group.

        :return: The is_group of this SignatureField.
        :rtype: bool
        """
        return self._is_group

    @is_group.setter
    def is_group(self, is_group):
        """
        Sets the is_group of this SignatureField.
        Is group.

        :param is_group: The is_group of this SignatureField.
        :type: bool
        """

        self._is_group = is_group

    @property
    def parent(self):
        """
        Gets the parent of this SignatureField.
        Gets field parent.

        :return: The parent of this SignatureField.
        :rtype: FormField
        """
        return self._parent

    @parent.setter
    def parent(self, parent):
        """
        Sets the parent of this SignatureField.
        Gets field parent.

        :param parent: The parent of this SignatureField.
        :type: FormField
        """

        self._parent = parent

    @property
    def is_shared_field(self):
        """
        Gets the is_shared_field of this SignatureField.
        Property for Generator support. Used when field is added to header or footer. If true, this field will created once and it's appearance will be visible on all pages of the document. If false, separated field will be created for every document page.

        :return: The is_shared_field of this SignatureField.
        :rtype: bool
        """
        return self._is_shared_field

    @is_shared_field.setter
    def is_shared_field(self, is_shared_field):
        """
        Sets the is_shared_field of this SignatureField.
        Property for Generator support. Used when field is added to header or footer. If true, this field will created once and it's appearance will be visible on all pages of the document. If false, separated field will be created for every document page.

        :param is_shared_field: The is_shared_field of this SignatureField.
        :type: bool
        """

        self._is_shared_field = is_shared_field

    @property
    def flags(self):
        """
        Gets the flags of this SignatureField.
        Gets Flags of the field.

        :return: The flags of this SignatureField.
        :rtype: list[AnnotationFlags]
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """
        Sets the flags of this SignatureField.
        Gets Flags of the field.

        :param flags: The flags of this SignatureField.
        :type: list[AnnotationFlags]
        """

        self._flags = flags

    @property
    def color(self):
        """
        Gets the color of this SignatureField.
        Color of the annotation.

        :return: The color of this SignatureField.
        :rtype: Color
        """
        return self._color

    @color.setter
    def color(self, color):
        """
        Sets the color of this SignatureField.
        Color of the annotation.

        :param color: The color of this SignatureField.
        :type: Color
        """

        self._color = color

    @property
    def contents(self):
        """
        Gets the contents of this SignatureField.
        Get the field content.

        :return: The contents of this SignatureField.
        :rtype: str
        """
        return self._contents

    @contents.setter
    def contents(self, contents):
        """
        Sets the contents of this SignatureField.
        Get the field content.

        :param contents: The contents of this SignatureField.
        :type: str
        """

        self._contents = contents

    @property
    def margin(self):
        """
        Gets the margin of this SignatureField.
        Gets or sets a outer margin for paragraph (for pdf generation)

        :return: The margin of this SignatureField.
        :rtype: MarginInfo
        """
        return self._margin

    @margin.setter
    def margin(self, margin):
        """
        Sets the margin of this SignatureField.
        Gets or sets a outer margin for paragraph (for pdf generation)

        :param margin: The margin of this SignatureField.
        :type: MarginInfo
        """

        self._margin = margin

    @property
    def highlighting(self):
        """
        Gets the highlighting of this SignatureField.
        Field highlighting mode.

        :return: The highlighting of this SignatureField.
        :rtype: LinkHighlightingMode
        """
        return self._highlighting

    @highlighting.setter
    def highlighting(self, highlighting):
        """
        Sets the highlighting of this SignatureField.
        Field highlighting mode.

        :param highlighting: The highlighting of this SignatureField.
        :type: LinkHighlightingMode
        """

        self._highlighting = highlighting

    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment of this SignatureField.
        Gets HorizontalAlignment of the field.

        :return: The horizontal_alignment of this SignatureField.
        :rtype: HorizontalAlignment
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment of this SignatureField.
        Gets HorizontalAlignment of the field.

        :param horizontal_alignment: The horizontal_alignment of this SignatureField.
        :type: HorizontalAlignment
        """

        self._horizontal_alignment = horizontal_alignment

    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment of this SignatureField.
        Gets VerticalAlignment of the field.

        :return: The vertical_alignment of this SignatureField.
        :rtype: VerticalAlignment
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment of this SignatureField.
        Gets VerticalAlignment of the field.

        :param vertical_alignment: The vertical_alignment of this SignatureField.
        :type: VerticalAlignment
        """

        self._vertical_alignment = vertical_alignment

    @property
    def border(self):
        """
        Gets the border of this SignatureField.
        Gets or sets annotation border characteristics.

        :return: The border of this SignatureField.
        :rtype: Border
        """
        return self._border

    @border.setter
    def border(self, border):
        """
        Sets the border of this SignatureField.
        Gets or sets annotation border characteristics.

        :param border: The border of this SignatureField.
        :type: Border
        """

        self._border = border

    @property
    def signature(self):
        """
        Gets the signature of this SignatureField.
        Gets signature object. This object contains signature data regarding public-key cryptographic standards. Classes PKCS1, PKCS7 and PKCS7Detached represent all supported types of signature objects.

        :return: The signature of this SignatureField.
        :rtype: Signature
        """
        return self._signature

    @signature.setter
    def signature(self, signature):
        """
        Sets the signature of this SignatureField.
        Gets signature object. This object contains signature data regarding public-key cryptographic standards. Classes PKCS1, PKCS7 and PKCS7Detached represent all supported types of signature objects.

        :param signature: The signature of this SignatureField.
        :type: Signature
        """

        self._signature = signature

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SignatureField):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class StampInfo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[Link]',
        'id': 'str',
        'index_on_page': 'int',
        'page_index': 'int',
        'rect': 'Rectangle',
        'text': 'str',
        'visible': 'bool',
        'stamp_type': 'StampType'
    }

    attribute_map = {
        'links': 'Links',
        'id': 'Id',
        'index_on_page': 'IndexOnPage',
        'page_index': 'PageIndex',
        'rect': 'Rect',
        'text': 'Text',
        'visible': 'Visible',
        'stamp_type': 'StampType'
    }

    def __init__(self, links=None, id=None, index_on_page=None, page_index=None, rect=None, text=None, visible=None, stamp_type=None):
        """
        StampInfo - a model defined in Swagger
        """

        self._links = None
        self._id = None
        self._index_on_page = None
        self._page_index = None
        self._rect = None
        self._text = None
        self._visible = None
        self._stamp_type = None

        if links is not None:
          self.links = links
        if id is not None:
          self.id = id
        if index_on_page is not None:
          self.index_on_page = index_on_page
        if page_index is not None:
          self.page_index = page_index
        if rect is not None:
          self.rect = rect
        if text is not None:
          self.text = text
        if visible is not None:
          self.visible = visible
        self.stamp_type = stamp_type

    @property
    def links(self):
        """
        Gets the links of this StampInfo.
        Link to the document.

        :return: The links of this StampInfo.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this StampInfo.
        Link to the document.

        :param links: The links of this StampInfo.
        :type: list[Link]
        """

        self._links = links

    @property
    def id(self):
        """
        Gets the id of this StampInfo.
        Gets ID of the stamp.

        :return: The id of this StampInfo.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this StampInfo.
        Gets ID of the stamp.

        :param id: The id of this StampInfo.
        :type: str
        """

        self._id = id

    @property
    def index_on_page(self):
        """
        Gets the index_on_page of this StampInfo.
        Gets index on page of the stamp.

        :return: The index_on_page of this StampInfo.
        :rtype: int
        """
        return self._index_on_page

    @index_on_page.setter
    def index_on_page(self, index_on_page):
        """
        Sets the index_on_page of this StampInfo.
        Gets index on page of the stamp.

        :param index_on_page: The index_on_page of this StampInfo.
        :type: int
        """

        self._index_on_page = index_on_page

    @property
    def page_index(self):
        """
        Gets the page_index of this StampInfo.
        Gets PageIndex of the annotation.

        :return: The page_index of this StampInfo.
        :rtype: int
        """
        return self._page_index

    @page_index.setter
    def page_index(self, page_index):
        """
        Sets the page_index of this StampInfo.
        Gets PageIndex of the annotation.

        :param page_index: The page_index of this StampInfo.
        :type: int
        """

        self._page_index = page_index

    @property
    def rect(self):
        """
        Gets the rect of this StampInfo.
        Gets Rect of the annotation.

        :return: The rect of this StampInfo.
        :rtype: Rectangle
        """
        return self._rect

    @rect.setter
    def rect(self, rect):
        """
        Sets the rect of this StampInfo.
        Gets Rect of the annotation.

        :param rect: The rect of this StampInfo.
        :type: Rectangle
        """

        self._rect = rect

    @property
    def text(self):
        """
        Gets the text of this StampInfo.
        Get the text content.

        :return: The text of this StampInfo.
        :rtype: str
        """
        return self._text

    @text.setter
    def text(self, text):
        """
        Sets the text of this StampInfo.
        Get the text content.

        :param text: The text of this StampInfo.
        :type: str
        """

        self._text = text

    @property
    def visible(self):
        """
        Gets the visible of this StampInfo.
        Gets the stamp is visible.

        :return: The visible of this StampInfo.
        :rtype: bool
        """
        return self._visible

    @visible.setter
    def visible(self, visible):
        """
        Sets the visible of this StampInfo.
        Gets the stamp is visible.

        :param visible: The visible of this StampInfo.
        :type: bool
        """

        self._visible = visible

    @property
    def stamp_type(self):
        """
        Gets the stamp_type of this StampInfo.
        Gets stamp type.

        :return: The stamp_type of this StampInfo.
        :rtype: StampType
        """
        return self._stamp_type

    @stamp_type.setter
    def stamp_type(self, stamp_type):
        """
        Sets the stamp_type of this StampInfo.
        Gets stamp type.

        :param stamp_type: The stamp_type of this StampInfo.
        :type: StampType
        """
        if stamp_type is None:
            raise ValueError("Invalid value for `stamp_type`, must not be `None`")

        self._stamp_type = stamp_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, StampInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class Row(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'background_color': 'Color',
        'border': 'BorderInfo',
        'cells': 'list[Cell]',
        'default_cell_border': 'BorderInfo',
        'min_row_height': 'float',
        'fixed_row_height': 'float',
        'is_in_new_page': 'bool',
        'is_row_broken': 'bool',
        'default_cell_text_state': 'TextState',
        'default_cell_padding': 'MarginInfo',
        'vertical_alignment': 'VerticalAlignment'
    }

    attribute_map = {
        'background_color': 'BackgroundColor',
        'border': 'Border',
        'cells': 'Cells',
        'default_cell_border': 'DefaultCellBorder',
        'min_row_height': 'MinRowHeight',
        'fixed_row_height': 'FixedRowHeight',
        'is_in_new_page': 'IsInNewPage',
        'is_row_broken': 'IsRowBroken',
        'default_cell_text_state': 'DefaultCellTextState',
        'default_cell_padding': 'DefaultCellPadding',
        'vertical_alignment': 'VerticalAlignment'
    }

    def __init__(self, background_color=None, border=None, cells=None, default_cell_border=None, min_row_height=None, fixed_row_height=None, is_in_new_page=None, is_row_broken=None, default_cell_text_state=None, default_cell_padding=None, vertical_alignment=None):
        """
        Row - a model defined in Swagger
        """

        self._background_color = None
        self._border = None
        self._cells = None
        self._default_cell_border = None
        self._min_row_height = None
        self._fixed_row_height = None
        self._is_in_new_page = None
        self._is_row_broken = None
        self._default_cell_text_state = None
        self._default_cell_padding = None
        self._vertical_alignment = None

        if background_color is not None:
          self.background_color = background_color
        if border is not None:
          self.border = border
        self.cells = cells
        if default_cell_border is not None:
          self.default_cell_border = default_cell_border
        if min_row_height is not None:
          self.min_row_height = min_row_height
        if fixed_row_height is not None:
          self.fixed_row_height = fixed_row_height
        if is_in_new_page is not None:
          self.is_in_new_page = is_in_new_page
        if is_row_broken is not None:
          self.is_row_broken = is_row_broken
        if default_cell_text_state is not None:
          self.default_cell_text_state = default_cell_text_state
        if default_cell_padding is not None:
          self.default_cell_padding = default_cell_padding
        if vertical_alignment is not None:
          self.vertical_alignment = vertical_alignment

    @property
    def background_color(self):
        """
        Gets the background_color of this Row.
        Gets or sets the background color.

        :return: The background_color of this Row.
        :rtype: Color
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color of this Row.
        Gets or sets the background color.

        :param background_color: The background_color of this Row.
        :type: Color
        """

        self._background_color = background_color

    @property
    def border(self):
        """
        Gets the border of this Row.
        Gets or sets the border.

        :return: The border of this Row.
        :rtype: BorderInfo
        """
        return self._border

    @border.setter
    def border(self, border):
        """
        Sets the border of this Row.
        Gets or sets the border.

        :param border: The border of this Row.
        :type: BorderInfo
        """

        self._border = border

    @property
    def cells(self):
        """
        Gets the cells of this Row.
        Sets the cells of the row.

        :return: The cells of this Row.
        :rtype: list[Cell]
        """
        return self._cells

    @cells.setter
    def cells(self, cells):
        """
        Sets the cells of this Row.
        Sets the cells of the row.

        :param cells: The cells of this Row.
        :type: list[Cell]
        """
        if cells is None:
            raise ValueError("Invalid value for `cells`, must not be `None`")

        self._cells = cells

    @property
    def default_cell_border(self):
        """
        Gets the default_cell_border of this Row.
        Gets default cell border;

        :return: The default_cell_border of this Row.
        :rtype: BorderInfo
        """
        return self._default_cell_border

    @default_cell_border.setter
    def default_cell_border(self, default_cell_border):
        """
        Sets the default_cell_border of this Row.
        Gets default cell border;

        :param default_cell_border: The default_cell_border of this Row.
        :type: BorderInfo
        """

        self._default_cell_border = default_cell_border

    @property
    def min_row_height(self):
        """
        Gets the min_row_height of this Row.
        Gets height for row;

        :return: The min_row_height of this Row.
        :rtype: float
        """
        return self._min_row_height

    @min_row_height.setter
    def min_row_height(self, min_row_height):
        """
        Sets the min_row_height of this Row.
        Gets height for row;

        :param min_row_height: The min_row_height of this Row.
        :type: float
        """

        self._min_row_height = min_row_height

    @property
    def fixed_row_height(self):
        """
        Gets the fixed_row_height of this Row.
        Gets fixed row height - row may have fixed height;

        :return: The fixed_row_height of this Row.
        :rtype: float
        """
        return self._fixed_row_height

    @fixed_row_height.setter
    def fixed_row_height(self, fixed_row_height):
        """
        Sets the fixed_row_height of this Row.
        Gets fixed row height - row may have fixed height;

        :param fixed_row_height: The fixed_row_height of this Row.
        :type: float
        """

        self._fixed_row_height = fixed_row_height

    @property
    def is_in_new_page(self):
        """
        Gets the is_in_new_page of this Row.
        Gets fixed row is in new page - page with this property should be printed to next page Default false;

        :return: The is_in_new_page of this Row.
        :rtype: bool
        """
        return self._is_in_new_page

    @is_in_new_page.setter
    def is_in_new_page(self, is_in_new_page):
        """
        Sets the is_in_new_page of this Row.
        Gets fixed row is in new page - page with this property should be printed to next page Default false;

        :param is_in_new_page: The is_in_new_page of this Row.
        :type: bool
        """

        self._is_in_new_page = is_in_new_page

    @property
    def is_row_broken(self):
        """
        Gets the is_row_broken of this Row.
        Gets is row can be broken between two pages

        :return: The is_row_broken of this Row.
        :rtype: bool
        """
        return self._is_row_broken

    @is_row_broken.setter
    def is_row_broken(self, is_row_broken):
        """
        Sets the is_row_broken of this Row.
        Gets is row can be broken between two pages

        :param is_row_broken: The is_row_broken of this Row.
        :type: bool
        """

        self._is_row_broken = is_row_broken

    @property
    def default_cell_text_state(self):
        """
        Gets the default_cell_text_state of this Row.
        Gets or sets default text state for row cells

        :return: The default_cell_text_state of this Row.
        :rtype: TextState
        """
        return self._default_cell_text_state

    @default_cell_text_state.setter
    def default_cell_text_state(self, default_cell_text_state):
        """
        Sets the default_cell_text_state of this Row.
        Gets or sets default text state for row cells

        :param default_cell_text_state: The default_cell_text_state of this Row.
        :type: TextState
        """

        self._default_cell_text_state = default_cell_text_state

    @property
    def default_cell_padding(self):
        """
        Gets the default_cell_padding of this Row.
        Gets or sets default margin for row cells

        :return: The default_cell_padding of this Row.
        :rtype: MarginInfo
        """
        return self._default_cell_padding

    @default_cell_padding.setter
    def default_cell_padding(self, default_cell_padding):
        """
        Sets the default_cell_padding of this Row.
        Gets or sets default margin for row cells

        :param default_cell_padding: The default_cell_padding of this Row.
        :type: MarginInfo
        """

        self._default_cell_padding = default_cell_padding

    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment of this Row.
        Gets or sets the vertical alignment.

        :return: The vertical_alignment of this Row.
        :rtype: VerticalAlignment
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment of this Row.
        Gets or sets the vertical alignment.

        :param vertical_alignment: The vertical_alignment of this Row.
        :type: VerticalAlignment
        """

        self._vertical_alignment = vertical_alignment

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Row):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *
file_name = 'PdfWithXfaForm.pdf'
result_file_name = "result.pdf"

opts = {
    "file": test_data_path + file_name
}

response = pdf_api.put_xfa_pdf_in_request_to_acro_form(
    temp_folder + '/' + result_file_name, **opts)


pprint(response)


from configuration import *
file_name = 'PdfWithXfaForm.pdf'
uploadFile(file_name)

opts = {
    "folder": temp_folder
}

response = pdf_api.get_xfa_pdf_in_storage_to_acro_form(file_name, **opts)

pprint(response)



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from __future__ import absolute_import

import io
import json
import ssl
import certifi
import logging
import re

# python 2 and python 3 compatibility library
from six import PY3
from six.moves.urllib.parse import urlencode

from .configuration import Configuration

try:
    import urllib3
except ImportError:
    raise ImportError('Swagger python client requires urllib3.')


logger = logging.getLogger(__name__)


class RESTResponse(io.IOBase):

    def __init__(self, resp):
        self.urllib3_response = resp
        self.status = resp.status
        self.reason = resp.reason
        self.data = resp.data

    def getheaders(self):
        """
        Returns a dictionary of the response headers.
        """
        return self.urllib3_response.getheaders()

    def getheader(self, name, default=None):
        """
        Returns a given response header.
        """
        return self.urllib3_response.getheader(name, default)


class RESTClientObject(object):

    def __init__(self, pools_size=4, maxsize=4):
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680
        # maxsize is the number of requests to host that are allowed in parallel
        # ca_certs vs cert_file vs key_file
        # http://stackoverflow.com/a/23957365/2985775

        # cert_reqs
        if Configuration().verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        # ca_certs
        if Configuration().ssl_ca_cert:
            ca_certs = Configuration().ssl_ca_cert
        else:
            # if not set certificate file, use Mozilla's root certificates.
            ca_certs = certifi.where()

        # cert_file
        cert_file = Configuration().cert_file

        # key file
        key_file = Configuration().key_file

        # proxy
        proxy = Configuration().proxy

        # https pool manager
        if proxy:
            self.pool_manager = urllib3.ProxyManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=cert_file,
                key_file=key_file,
                proxy_url=proxy
            )
        else:
            self.pool_manager = urllib3.PoolManager(
                num_pools=pools_size,
                maxsize=maxsize,
                cert_reqs=cert_reqs,
                ca_certs=ca_certs,
                cert_file=cert_file,
                key_file=key_file
            )


    def request(self, method, url, query_params=None, headers=None,
                body=None, post_params=None, _preload_content=True, _request_timeout=None):
        """
        :param method: http request method
        :param url: http request url
        :param query_params: query parameters in the url
        :param headers: http request headers
        :param body: request json body, for `application/json`
        :param post_params: request post parameters,
                            `application/x-www-form-urlencoded`
                            and `multipart/form-data`
        :param _preload_content: if False, the urllib3.HTTPResponse object will be returned without
                                 reading/decoding response data. Default is True.
        :param _request_timeout: timeout setting for this request. If one number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of (connection, read) timeouts.
        """
        method = method.upper()
        assert method in ['GET', 'HEAD', 'DELETE', 'POST', 'PUT', 'PATCH', 'OPTIONS']

        if post_params and body:
            raise ValueError(
                "body parameter cannot be used with post_params parameter."
            )

        post_params = post_params or {}
        headers = headers or {}

        timeout = 5 * 60
        if _request_timeout:
            if isinstance(_request_timeout, (int, ) if PY3 else (int, long)):
                timeout = urllib3.Timeout(total=_request_timeout)
            elif isinstance(_request_timeout, tuple) and len(_request_timeout) == 2:
                timeout = urllib3.Timeout(connect=_request_timeout[0], read=_request_timeout[1])

        if 'Content-Type' not in headers:
            headers['Content-Type'] = 'application/json'

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:
                if query_params:
                    url += '?' + urlencode(query_params)
                if re.search('json', headers['Content-Type'], re.IGNORECASE):
                    request_body = None
                    if body:
                        request_body = json.dumps(body)
                    r = self.pool_manager.request(method, url,
                                                  body=request_body,
                                                  preload_content=_preload_content,
                                                  timeout=timeout,
                                                  headers=headers)
                elif headers['Content-Type'] == 'application/x-www-form-urlencoded':
                    r = self.pool_manager.request(method, url,
                                                  fields=post_params,
                                                  encode_multipart=False,
                                                  preload_content=_preload_content,
                                                  timeout=timeout,
                                                  headers=headers)
                elif headers['Content-Type'] == 'multipart/form-data':
                    # must del headers['Content-Type'], or the correct Content-Type
                    # which generated by urllib3 will be overwritten.
                    del headers['Content-Type']
                    r = self.pool_manager.request(method, url,
                                                  fields=post_params,
                                                  encode_multipart=True,
                                                  preload_content=_preload_content,
                                                  timeout=timeout,
                                                  headers=headers)
                # Pass a `string` parameter directly in the body to support
                # other content types than Json when `body` argument is provided
                # in serialized form
                elif isinstance(body, str):
                    request_body = body
                    r = self.pool_manager.request(method, url,
                                                  body=request_body,
                                                  preload_content=_preload_content,
                                                  timeout=timeout,
                                                  headers=headers)
                # TEMPLATE CHANGED
                elif PY3 and isinstance(body, bytes):
                    request_body = body
                    r = self.pool_manager.request(method, url,
                                                  body=request_body,
                                                  preload_content=_preload_content,
                                                  timeout=timeout,
                                                  headers=headers)
                # TEMPLATE CHANGED

                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided arguments.
                             Please check that your arguments match declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(method, url,
                                              fields=query_params,
                                              preload_content=_preload_content,
                                              timeout=timeout,
                                              headers=headers)
        except urllib3.exceptions.SSLError as e:
            msg = "{0}\n{1}".format(type(e).__name__, str(e))
            raise ApiException(status=0, reason=msg)

        #TEMPLATE CHANGE
        if _preload_content:
            content_type = ''
            if 'Content-Type' in r.headers.keys(): 
                content_type = r.headers['Content-Type']
            r = RESTResponse(r)

            # In the python 3, the response.data is bytes.
            # we need to decode it to string.
            if PY3 and 'application/json' in content_type:
                r.data = r.data.decode('utf8')

            # log response body
            logger.debug("response body: %s", r.data)

        if not 200 <= r.status <= 299:
            raise ApiException(http_resp=r)

        return r

    def GET(self, url, headers=None, query_params=None, _preload_content=True, _request_timeout=None):
        return self.request("GET", url,
                            headers=headers,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            query_params=query_params)

    def HEAD(self, url, headers=None, query_params=None, _preload_content=True, _request_timeout=None):
        return self.request("HEAD", url,
                            headers=headers,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            query_params=query_params)

    def OPTIONS(self, url, headers=None, query_params=None, post_params=None, body=None, _preload_content=True,
                _request_timeout=None):
        return self.request("OPTIONS", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def DELETE(self, url, headers=None, query_params=None, body=None, _preload_content=True, _request_timeout=None):
        return self.request("DELETE", url,
                            headers=headers,
                            query_params=query_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def POST(self, url, headers=None, query_params=None, post_params=None, body=None, _preload_content=True,
             _request_timeout=None):
        return self.request("POST", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def PUT(self, url, headers=None, query_params=None, post_params=None, body=None, _preload_content=True,
            _request_timeout=None):
        return self.request("PUT", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)

    def PATCH(self, url, headers=None, query_params=None, post_params=None, body=None, _preload_content=True,
              _request_timeout=None):
        return self.request("PATCH", url,
                            headers=headers,
                            query_params=query_params,
                            post_params=post_params,
                            _preload_content=_preload_content,
                            _request_timeout=_request_timeout,
                            body=body)


class ApiException(Exception):

    def __init__(self, status=None, reason=None, http_resp=None):
        if http_resp:
            self.status = http_resp.status
            self.reason = http_resp.reason
            self.body = http_resp.data
            self.headers = http_resp.getheaders()
        else:
            self.status = status
            self.reason = reason
            self.body = None
            self.headers = None

    def __str__(self):
        """
        Custom error messages for exception
        """
        error_message = "({0})\n"\
                        "Reason: {1}\n".format(self.status, self.reason)
        if self.headers:
            error_message += "HTTP response headers: {0}\n".format(self.headers)

        if self.body:
            error_message += "HTTP response body: {0}\n".format(self.body)

        return error_message



from configuration import *
file_name = 'HtmlWithImage.zip'
uploadFile(file_name)
html_file_name = 'HtmlWithImage.html'

result_name = 'fromMht.pdf'

src_path = temp_folder + '/' + file_name
opts = {
    "dst_folder": temp_folder,
    "height": 650,
    "width": 250,
    "html_file_name": html_file_name
}
response = pdf_api.put_html_in_storage_to_pdf(
    result_name, src_path, **opts)

pprint(response)



from configuration import *
file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

page_number = 1

annotation = asposepdfcloud.models.InkAnnotation()
annotation.name = 'Name'
annotation.rect = asposepdfcloud.models.Rectangle(
    llx=100, lly=100, urx=200, ury=200)
annotation.flags = [asposepdfcloud.models.AnnotationFlags.DEFAULT]
annotation.horizontal_alignment = asposepdfcloud.models.HorizontalAlignment.CENTER
annotation.rich_text = 'Rich Text'
annotation.subject = 'Subj'
annotation.z_index = 1
annotation.title = 'Title'
annotation.ink_list = [
    [
        asposepdfcloud.models.Point(10, 40),
        asposepdfcloud.models.Point(30, 40),
    ],
    [
        asposepdfcloud.models.Point(10, 20),
        asposepdfcloud.models.Point(20, 20),
        asposepdfcloud.models.Point(30, 20),
    ]
]
annotation.cap_style = asposepdfcloud.models.CapStyle.ROUNDED
annotation.modified = '02/02/2018 00:00:00.000 AM'

response = pdf_api.post_page_ink_annotations(
    file_name, page_number,  [annotation], folder=temp_folder)



from configuration import *

file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

text_style = asposepdfcloud.models.TextStyle(font_size=12, font='Arial',
                                             foreground_color=asposepdfcloud.models.Color(
                                                 a=0xFF, r=0, g=0xFF, b=0),
                                             background_color=asposepdfcloud.models.Color(a=0xFF, r=0xFF, g=0, b=0))

annotation = asposepdfcloud.models.FreeTextAnnotation()
annotation.name = 'Test Free Text'
annotation.text_style = text_style
annotation.rect = asposepdfcloud.models.Rectangle(
    llx=100, lly=100, urx=200, ury=200)
annotation.flags = [asposepdfcloud.models.AnnotationFlags.DEFAULT]
annotation.horizontal_alignment = asposepdfcloud.models.HorizontalAlignment.CENTER
annotation.intent = asposepdfcloud.models.FreeTextIntent.FREETEXTTYPEWRITER
annotation.rich_text = 'Rich Text'
annotation.subject = 'Text Box Subj'
annotation.z_index = 1
annotation.justification = asposepdfcloud.models.Justification.CENTER
annotation.title = 'Title'

response_annotations = pdf_api.get_document_free_text_annotations(
    file_name, folder=temp_folder)
annotation_id = response_annotations.annotations.list[0].id

response = pdf_api.put_free_text_annotation(
    file_name, annotation_id, annotation, folder=temp_folder)

pprint(response)



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class ImageTemplate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'image_path': 'str',
        'image_src_type': 'ImageSrcType',
        'left_margin': 'float',
        'right_margin': 'float',
        'top_margin': 'float',
        'bottom_margin': 'float',
        'page_width': 'float',
        'page_height': 'float',
        'margin_info': 'MarginInfo'
    }

    attribute_map = {
        'image_path': 'ImagePath',
        'image_src_type': 'ImageSrcType',
        'left_margin': 'LeftMargin',
        'right_margin': 'RightMargin',
        'top_margin': 'TopMargin',
        'bottom_margin': 'BottomMargin',
        'page_width': 'PageWidth',
        'page_height': 'PageHeight',
        'margin_info': 'MarginInfo'
    }

    def __init__(self, image_path=None, image_src_type=None, left_margin=None, right_margin=None, top_margin=None, bottom_margin=None, page_width=None, page_height=None, margin_info=None):
        """
        ImageTemplate - a model defined in Swagger
        """

        self._image_path = None
        self._image_src_type = None
        self._left_margin = None
        self._right_margin = None
        self._top_margin = None
        self._bottom_margin = None
        self._page_width = None
        self._page_height = None
        self._margin_info = None

        self.image_path = image_path
        self.image_src_type = image_src_type
        if left_margin is not None:
          self.left_margin = left_margin
        if right_margin is not None:
          self.right_margin = right_margin
        if top_margin is not None:
          self.top_margin = top_margin
        if bottom_margin is not None:
          self.bottom_margin = bottom_margin
        if page_width is not None:
          self.page_width = page_width
        if page_height is not None:
          self.page_height = page_height
        if margin_info is not None:
          self.margin_info = margin_info

    @property
    def image_path(self):
        """
        Gets the image_path of this ImageTemplate.
        A path for image.

        :return: The image_path of this ImageTemplate.
        :rtype: str
        """
        return self._image_path

    @image_path.setter
    def image_path(self, image_path):
        """
        Sets the image_path of this ImageTemplate.
        A path for image.

        :param image_path: The image_path of this ImageTemplate.
        :type: str
        """
        if image_path is None:
            raise ValueError("Invalid value for `image_path`, must not be `None`")
        if image_path is not None and len(image_path) < 1:
            raise ValueError("Invalid value for `image_path`, length must be greater than or equal to `1`")

        self._image_path = image_path

    @property
    def image_src_type(self):
        """
        Gets the image_src_type of this ImageTemplate.
        Image type.

        :return: The image_src_type of this ImageTemplate.
        :rtype: ImageSrcType
        """
        return self._image_src_type

    @image_src_type.setter
    def image_src_type(self, image_src_type):
        """
        Sets the image_src_type of this ImageTemplate.
        Image type.

        :param image_src_type: The image_src_type of this ImageTemplate.
        :type: ImageSrcType
        """
        if image_src_type is None:
            raise ValueError("Invalid value for `image_src_type`, must not be `None`")

        self._image_src_type = image_src_type

    @property
    def left_margin(self):
        """
        Gets the left_margin of this ImageTemplate.

        :return: The left_margin of this ImageTemplate.
        :rtype: float
        """
        return self._left_margin

    @left_margin.setter
    def left_margin(self, left_margin):
        """
        Sets the left_margin of this ImageTemplate.

        :param left_margin: The left_margin of this ImageTemplate.
        :type: float
        """

        self._left_margin = left_margin

    @property
    def right_margin(self):
        """
        Gets the right_margin of this ImageTemplate.

        :return: The right_margin of this ImageTemplate.
        :rtype: float
        """
        return self._right_margin

    @right_margin.setter
    def right_margin(self, right_margin):
        """
        Sets the right_margin of this ImageTemplate.

        :param right_margin: The right_margin of this ImageTemplate.
        :type: float
        """

        self._right_margin = right_margin

    @property
    def top_margin(self):
        """
        Gets the top_margin of this ImageTemplate.

        :return: The top_margin of this ImageTemplate.
        :rtype: float
        """
        return self._top_margin

    @top_margin.setter
    def top_margin(self, top_margin):
        """
        Sets the top_margin of this ImageTemplate.

        :param top_margin: The top_margin of this ImageTemplate.
        :type: float
        """

        self._top_margin = top_margin

    @property
    def bottom_margin(self):
        """
        Gets the bottom_margin of this ImageTemplate.

        :return: The bottom_margin of this ImageTemplate.
        :rtype: float
        """
        return self._bottom_margin

    @bottom_margin.setter
    def bottom_margin(self, bottom_margin):
        """
        Sets the bottom_margin of this ImageTemplate.

        :param bottom_margin: The bottom_margin of this ImageTemplate.
        :type: float
        """

        self._bottom_margin = bottom_margin

    @property
    def page_width(self):
        """
        Gets the page_width of this ImageTemplate.

        :return: The page_width of this ImageTemplate.
        :rtype: float
        """
        return self._page_width

    @page_width.setter
    def page_width(self, page_width):
        """
        Sets the page_width of this ImageTemplate.

        :param page_width: The page_width of this ImageTemplate.
        :type: float
        """

        self._page_width = page_width

    @property
    def page_height(self):
        """
        Gets the page_height of this ImageTemplate.

        :return: The page_height of this ImageTemplate.
        :rtype: float
        """
        return self._page_height

    @page_height.setter
    def page_height(self, page_height):
        """
        Sets the page_height of this ImageTemplate.

        :param page_height: The page_height of this ImageTemplate.
        :type: float
        """

        self._page_height = page_height

    @property
    def margin_info(self):
        """
        Gets the margin_info of this ImageTemplate.

        :return: The margin_info of this ImageTemplate.
        :rtype: MarginInfo
        """
        return self._margin_info

    @margin_info.setter
    def margin_info(self, margin_info):
        """
        Sets the margin_info of this ImageTemplate.

        :param margin_info: The margin_info of this ImageTemplate.
        :type: MarginInfo
        """

        self._margin_info = margin_info

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ImageTemplate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class Bookmark(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[Link]',
        'title': 'str',
        'italic': 'bool',
        'bold': 'bool',
        'color': 'Color',
        'action': 'str',
        'level': 'int',
        'destination': 'str',
        'page_display': 'str',
        'page_display_bottom': 'int',
        'page_display_left': 'int',
        'page_display_right': 'int',
        'page_display_top': 'int',
        'page_display_zoom': 'int',
        'page_number': 'int',
        'remote_file': 'str',
        'bookmarks': 'Bookmarks'
    }

    attribute_map = {
        'links': 'Links',
        'title': 'Title',
        'italic': 'Italic',
        'bold': 'Bold',
        'color': 'Color',
        'action': 'Action',
        'level': 'Level',
        'destination': 'Destination',
        'page_display': 'PageDisplay',
        'page_display_bottom': 'PageDisplay_Bottom',
        'page_display_left': 'PageDisplay_Left',
        'page_display_right': 'PageDisplay_Right',
        'page_display_top': 'PageDisplay_Top',
        'page_display_zoom': 'PageDisplay_Zoom',
        'page_number': 'PageNumber',
        'remote_file': 'RemoteFile',
        'bookmarks': 'Bookmarks'
    }

    def __init__(self, links=None, title=None, italic=None, bold=None, color=None, action=None, level=None, destination=None, page_display=None, page_display_bottom=None, page_display_left=None, page_display_right=None, page_display_top=None, page_display_zoom=None, page_number=None, remote_file=None, bookmarks=None):
        """
        Bookmark - a model defined in Swagger
        """

        self._links = None
        self._title = None
        self._italic = None
        self._bold = None
        self._color = None
        self._action = None
        self._level = None
        self._destination = None
        self._page_display = None
        self._page_display_bottom = None
        self._page_display_left = None
        self._page_display_right = None
        self._page_display_top = None
        self._page_display_zoom = None
        self._page_number = None
        self._remote_file = None
        self._bookmarks = None

        if links is not None:
          self.links = links
        if title is not None:
          self.title = title
        if italic is not None:
          self.italic = italic
        if bold is not None:
          self.bold = bold
        if color is not None:
          self.color = color
        if action is not None:
          self.action = action
        if level is not None:
          self.level = level
        if destination is not None:
          self.destination = destination
        if page_display is not None:
          self.page_display = page_display
        if page_display_bottom is not None:
          self.page_display_bottom = page_display_bottom
        if page_display_left is not None:
          self.page_display_left = page_display_left
        if page_display_right is not None:
          self.page_display_right = page_display_right
        if page_display_top is not None:
          self.page_display_top = page_display_top
        if page_display_zoom is not None:
          self.page_display_zoom = page_display_zoom
        if page_number is not None:
          self.page_number = page_number
        if remote_file is not None:
          self.remote_file = remote_file
        if bookmarks is not None:
          self.bookmarks = bookmarks

    @property
    def links(self):
        """
        Gets the links of this Bookmark.
        Link to the document.

        :return: The links of this Bookmark.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this Bookmark.
        Link to the document.

        :param links: The links of this Bookmark.
        :type: list[Link]
        """

        self._links = links

    @property
    def title(self):
        """
        Gets the title of this Bookmark.
        Get the Title;

        :return: The title of this Bookmark.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this Bookmark.
        Get the Title;

        :param title: The title of this Bookmark.
        :type: str
        """

        self._title = title

    @property
    def italic(self):
        """
        Gets the italic of this Bookmark.
        Is bookmark italic.

        :return: The italic of this Bookmark.
        :rtype: bool
        """
        return self._italic

    @italic.setter
    def italic(self, italic):
        """
        Sets the italic of this Bookmark.
        Is bookmark italic.

        :param italic: The italic of this Bookmark.
        :type: bool
        """

        self._italic = italic

    @property
    def bold(self):
        """
        Gets the bold of this Bookmark.
        Is bookmark bold.

        :return: The bold of this Bookmark.
        :rtype: bool
        """
        return self._bold

    @bold.setter
    def bold(self, bold):
        """
        Sets the bold of this Bookmark.
        Is bookmark bold.

        :param bold: The bold of this Bookmark.
        :type: bool
        """

        self._bold = bold

    @property
    def color(self):
        """
        Gets the color of this Bookmark.
        Get the color

        :return: The color of this Bookmark.
        :rtype: Color
        """
        return self._color

    @color.setter
    def color(self, color):
        """
        Sets the color of this Bookmark.
        Get the color

        :param color: The color of this Bookmark.
        :type: Color
        """

        self._color = color

    @property
    def action(self):
        """
        Gets the action of this Bookmark.
        Gets or sets the action bound with the bookmark. If PageNumber is presented the action can not be specified. The action type includes: \"GoTo\", \"GoToR\", \"Launch\", \"Named\".

        :return: The action of this Bookmark.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this Bookmark.
        Gets or sets the action bound with the bookmark. If PageNumber is presented the action can not be specified. The action type includes: \"GoTo\", \"GoToR\", \"Launch\", \"Named\".

        :param action: The action of this Bookmark.
        :type: str
        """

        self._action = action

    @property
    def level(self):
        """
        Gets the level of this Bookmark.
        Gets or sets bookmark's hierarchy level.

        :return: The level of this Bookmark.
        :rtype: int
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this Bookmark.
        Gets or sets bookmark's hierarchy level.

        :param level: The level of this Bookmark.
        :type: int
        """

        self._level = level

    @property
    def destination(self):
        """
        Gets the destination of this Bookmark.
        Gets or sets bookmark's destination page. Required if action is set as string.Empty.

        :return: The destination of this Bookmark.
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """
        Sets the destination of this Bookmark.
        Gets or sets bookmark's destination page. Required if action is set as string.Empty.

        :param destination: The destination of this Bookmark.
        :type: str
        """

        self._destination = destination

    @property
    def page_display(self):
        """
        Gets the page_display of this Bookmark.
        Gets or sets the type of display bookmark's destination page.

        :return: The page_display of this Bookmark.
        :rtype: str
        """
        return self._page_display

    @page_display.setter
    def page_display(self, page_display):
        """
        Sets the page_display of this Bookmark.
        Gets or sets the type of display bookmark's destination page.

        :param page_display: The page_display of this Bookmark.
        :type: str
        """

        self._page_display = page_display

    @property
    def page_display_bottom(self):
        """
        Gets the page_display_bottom of this Bookmark.
        Gets or sets the bottom coordinate of page display.

        :return: The page_display_bottom of this Bookmark.
        :rtype: int
        """
        return self._page_display_bottom

    @page_display_bottom.setter
    def page_display_bottom(self, page_display_bottom):
        """
        Sets the page_display_bottom of this Bookmark.
        Gets or sets the bottom coordinate of page display.

        :param page_display_bottom: The page_display_bottom of this Bookmark.
        :type: int
        """

        self._page_display_bottom = page_display_bottom

    @property
    def page_display_left(self):
        """
        Gets the page_display_left of this Bookmark.
        Gets or sets the left coordinate of page display.

        :return: The page_display_left of this Bookmark.
        :rtype: int
        """
        return self._page_display_left

    @page_display_left.setter
    def page_display_left(self, page_display_left):
        """
        Sets the page_display_left of this Bookmark.
        Gets or sets the left coordinate of page display.

        :param page_display_left: The page_display_left of this Bookmark.
        :type: int
        """

        self._page_display_left = page_display_left

    @property
    def page_display_right(self):
        """
        Gets the page_display_right of this Bookmark.
        Gets or sets the right coordinate of page display.

        :return: The page_display_right of this Bookmark.
        :rtype: int
        """
        return self._page_display_right

    @page_display_right.setter
    def page_display_right(self, page_display_right):
        """
        Sets the page_display_right of this Bookmark.
        Gets or sets the right coordinate of page display.

        :param page_display_right: The page_display_right of this Bookmark.
        :type: int
        """

        self._page_display_right = page_display_right

    @property
    def page_display_top(self):
        """
        Gets the page_display_top of this Bookmark.
        Gets or sets the top coordinate of page display.

        :return: The page_display_top of this Bookmark.
        :rtype: int
        """
        return self._page_display_top

    @page_display_top.setter
    def page_display_top(self, page_display_top):
        """
        Sets the page_display_top of this Bookmark.
        Gets or sets the top coordinate of page display.

        :param page_display_top: The page_display_top of this Bookmark.
        :type: int
        """

        self._page_display_top = page_display_top

    @property
    def page_display_zoom(self):
        """
        Gets the page_display_zoom of this Bookmark.
        Gets or sets the zoom factor of page display.

        :return: The page_display_zoom of this Bookmark.
        :rtype: int
        """
        return self._page_display_zoom

    @page_display_zoom.setter
    def page_display_zoom(self, page_display_zoom):
        """
        Sets the page_display_zoom of this Bookmark.
        Gets or sets the zoom factor of page display.

        :param page_display_zoom: The page_display_zoom of this Bookmark.
        :type: int
        """

        self._page_display_zoom = page_display_zoom

    @property
    def page_number(self):
        """
        Gets the page_number of this Bookmark.
        Gets or sets the number of bookmark's destination page. 

        :return: The page_number of this Bookmark.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this Bookmark.
        Gets or sets the number of bookmark's destination page. 

        :param page_number: The page_number of this Bookmark.
        :type: int
        """

        self._page_number = page_number

    @property
    def remote_file(self):
        """
        Gets the remote_file of this Bookmark.
        Gets or sets the file (path) which is required for \"GoToR\" action of bookmark.

        :return: The remote_file of this Bookmark.
        :rtype: str
        """
        return self._remote_file

    @remote_file.setter
    def remote_file(self, remote_file):
        """
        Sets the remote_file of this Bookmark.
        Gets or sets the file (path) which is required for \"GoToR\" action of bookmark.

        :param remote_file: The remote_file of this Bookmark.
        :type: str
        """

        self._remote_file = remote_file

    @property
    def bookmarks(self):
        """
        Gets the bookmarks of this Bookmark.
        The children bookmarks.

        :return: The bookmarks of this Bookmark.
        :rtype: Bookmarks
        """
        return self._bookmarks

    @bookmarks.setter
    def bookmarks(self, bookmarks):
        """
        Sets the bookmarks of this Bookmark.
        The children bookmarks.

        :param bookmarks: The bookmarks of this Bookmark.
        :type: Bookmarks
        """

        self._bookmarks = bookmarks

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Bookmark):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *

file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

response_annotations = pdf_api.get_document_stamp_annotations(
    file_name, folder=temp_folder)``
annotation_id = response_annotations.annotations.list[0].id

response = pdf_api.put_stamp_annotation_data_extract(
    file_name, annotation_id, out_file_path='stamp.dat', folder=temp_folder)

pprint(response)



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class SignatureCustomAppearance(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'font_family_name': 'str',
        'font_size': 'float',
        'show_contact_info': 'bool',
        'show_reason': 'bool',
        'show_location': 'bool',
        'contact_info_label': 'str',
        'reason_label': 'str',
        'location_label': 'str',
        'digital_signed_label': 'str',
        'date_signed_at_label': 'str',
        'date_time_local_format': 'str',
        'date_time_format': 'str'
    }

    attribute_map = {
        'font_family_name': 'FontFamilyName',
        'font_size': 'FontSize',
        'show_contact_info': 'ShowContactInfo',
        'show_reason': 'ShowReason',
        'show_location': 'ShowLocation',
        'contact_info_label': 'ContactInfoLabel',
        'reason_label': 'ReasonLabel',
        'location_label': 'LocationLabel',
        'digital_signed_label': 'DigitalSignedLabel',
        'date_signed_at_label': 'DateSignedAtLabel',
        'date_time_local_format': 'DateTimeLocalFormat',
        'date_time_format': 'DateTimeFormat'
    }

    def __init__(self, font_family_name=None, font_size=None, show_contact_info=None, show_reason=None, show_location=None, contact_info_label=None, reason_label=None, location_label=None, digital_signed_label=None, date_signed_at_label=None, date_time_local_format=None, date_time_format=None):
        """
        SignatureCustomAppearance - a model defined in Swagger
        """

        self._font_family_name = None
        self._font_size = None
        self._show_contact_info = None
        self._show_reason = None
        self._show_location = None
        self._contact_info_label = None
        self._reason_label = None
        self._location_label = None
        self._digital_signed_label = None
        self._date_signed_at_label = None
        self._date_time_local_format = None
        self._date_time_format = None

        if font_family_name is not None:
          self.font_family_name = font_family_name
        self.font_size = font_size
        self.show_contact_info = show_contact_info
        self.show_reason = show_reason
        self.show_location = show_location
        if contact_info_label is not None:
          self.contact_info_label = contact_info_label
        if reason_label is not None:
          self.reason_label = reason_label
        if location_label is not None:
          self.location_label = location_label
        if digital_signed_label is not None:
          self.digital_signed_label = digital_signed_label
        if date_signed_at_label is not None:
          self.date_signed_at_label = date_signed_at_label
        if date_time_local_format is not None:
          self.date_time_local_format = date_time_local_format
        if date_time_format is not None:
          self.date_time_format = date_time_format

    @property
    def font_family_name(self):
        """
        Gets the font_family_name of this SignatureCustomAppearance.
        Gets/sets font family name. It should be existed in the document. Default value: Arial.

        :return: The font_family_name of this SignatureCustomAppearance.
        :rtype: str
        """
        return self._font_family_name

    @font_family_name.setter
    def font_family_name(self, font_family_name):
        """
        Sets the font_family_name of this SignatureCustomAppearance.
        Gets/sets font family name. It should be existed in the document. Default value: Arial.

        :param font_family_name: The font_family_name of this SignatureCustomAppearance.
        :type: str
        """

        self._font_family_name = font_family_name

    @property
    def font_size(self):
        """
        Gets the font_size of this SignatureCustomAppearance.
        Gets/sets font size. Default value: 10.

        :return: The font_size of this SignatureCustomAppearance.
        :rtype: float
        """
        return self._font_size

    @font_size.setter
    def font_size(self, font_size):
        """
        Sets the font_size of this SignatureCustomAppearance.
        Gets/sets font size. Default value: 10.

        :param font_size: The font_size of this SignatureCustomAppearance.
        :type: float
        """
        if font_size is None:
            raise ValueError("Invalid value for `font_size`, must not be `None`")

        self._font_size = font_size

    @property
    def show_contact_info(self):
        """
        Gets the show_contact_info of this SignatureCustomAppearance.
        Gets/sets contact info visibility. Default value: true.

        :return: The show_contact_info of this SignatureCustomAppearance.
        :rtype: bool
        """
        return self._show_contact_info

    @show_contact_info.setter
    def show_contact_info(self, show_contact_info):
        """
        Sets the show_contact_info of this SignatureCustomAppearance.
        Gets/sets contact info visibility. Default value: true.

        :param show_contact_info: The show_contact_info of this SignatureCustomAppearance.
        :type: bool
        """
        if show_contact_info is None:
            raise ValueError("Invalid value for `show_contact_info`, must not be `None`")

        self._show_contact_info = show_contact_info

    @property
    def show_reason(self):
        """
        Gets the show_reason of this SignatureCustomAppearance.
        Gets/sets reason visibility. Default value: true.

        :return: The show_reason of this SignatureCustomAppearance.
        :rtype: bool
        """
        return self._show_reason

    @show_reason.setter
    def show_reason(self, show_reason):
        """
        Sets the show_reason of this SignatureCustomAppearance.
        Gets/sets reason visibility. Default value: true.

        :param show_reason: The show_reason of this SignatureCustomAppearance.
        :type: bool
        """
        if show_reason is None:
            raise ValueError("Invalid value for `show_reason`, must not be `None`")

        self._show_reason = show_reason

    @property
    def show_location(self):
        """
        Gets the show_location of this SignatureCustomAppearance.
        Gets/sets location visibility. Default value: true.

        :return: The show_location of this SignatureCustomAppearance.
        :rtype: bool
        """
        return self._show_location

    @show_location.setter
    def show_location(self, show_location):
        """
        Sets the show_location of this SignatureCustomAppearance.
        Gets/sets location visibility. Default value: true.

        :param show_location: The show_location of this SignatureCustomAppearance.
        :type: bool
        """
        if show_location is None:
            raise ValueError("Invalid value for `show_location`, must not be `None`")

        self._show_location = show_location

    @property
    def contact_info_label(self):
        """
        Gets the contact_info_label of this SignatureCustomAppearance.
        Gets/sets contact info label. Default value: \"Contact\".

        :return: The contact_info_label of this SignatureCustomAppearance.
        :rtype: str
        """
        return self._contact_info_label

    @contact_info_label.setter
    def contact_info_label(self, contact_info_label):
        """
        Sets the contact_info_label of this SignatureCustomAppearance.
        Gets/sets contact info label. Default value: \"Contact\".

        :param contact_info_label: The contact_info_label of this SignatureCustomAppearance.
        :type: str
        """

        self._contact_info_label = contact_info_label

    @property
    def reason_label(self):
        """
        Gets the reason_label of this SignatureCustomAppearance.
        Gets/sets reason label. Default value: \"Reason\".

        :return: The reason_label of this SignatureCustomAppearance.
        :rtype: str
        """
        return self._reason_label

    @reason_label.setter
    def reason_label(self, reason_label):
        """
        Sets the reason_label of this SignatureCustomAppearance.
        Gets/sets reason label. Default value: \"Reason\".

        :param reason_label: The reason_label of this SignatureCustomAppearance.
        :type: str
        """

        self._reason_label = reason_label

    @property
    def location_label(self):
        """
        Gets the location_label of this SignatureCustomAppearance.
        Gets/sets location label. Default value: \"Location\".

        :return: The location_label of this SignatureCustomAppearance.
        :rtype: str
        """
        return self._location_label

    @location_label.setter
    def location_label(self, location_label):
        """
        Sets the location_label of this SignatureCustomAppearance.
        Gets/sets location label. Default value: \"Location\".

        :param location_label: The location_label of this SignatureCustomAppearance.
        :type: str
        """

        self._location_label = location_label

    @property
    def digital_signed_label(self):
        """
        Gets the digital_signed_label of this SignatureCustomAppearance.
        Gets/sets digital signed label. Default value: \"Digitally signed by\".

        :return: The digital_signed_label of this SignatureCustomAppearance.
        :rtype: str
        """
        return self._digital_signed_label

    @digital_signed_label.setter
    def digital_signed_label(self, digital_signed_label):
        """
        Sets the digital_signed_label of this SignatureCustomAppearance.
        Gets/sets digital signed label. Default value: \"Digitally signed by\".

        :param digital_signed_label: The digital_signed_label of this SignatureCustomAppearance.
        :type: str
        """

        self._digital_signed_label = digital_signed_label

    @property
    def date_signed_at_label(self):
        """
        Gets the date_signed_at_label of this SignatureCustomAppearance.
        Gets/sets date signed label. Default value: \"Date\".

        :return: The date_signed_at_label of this SignatureCustomAppearance.
        :rtype: str
        """
        return self._date_signed_at_label

    @date_signed_at_label.setter
    def date_signed_at_label(self, date_signed_at_label):
        """
        Sets the date_signed_at_label of this SignatureCustomAppearance.
        Gets/sets date signed label. Default value: \"Date\".

        :param date_signed_at_label: The date_signed_at_label of this SignatureCustomAppearance.
        :type: str
        """

        self._date_signed_at_label = date_signed_at_label

    @property
    def date_time_local_format(self):
        """
        Gets the date_time_local_format of this SignatureCustomAppearance.
        Gets/sets datetime local format. Default value: \"yyyy.MM.dd HH:mm:ss zzz\".

        :return: The date_time_local_format of this SignatureCustomAppearance.
        :rtype: str
        """
        return self._date_time_local_format

    @date_time_local_format.setter
    def date_time_local_format(self, date_time_local_format):
        """
        Sets the date_time_local_format of this SignatureCustomAppearance.
        Gets/sets datetime local format. Default value: \"yyyy.MM.dd HH:mm:ss zzz\".

        :param date_time_local_format: The date_time_local_format of this SignatureCustomAppearance.
        :type: str
        """

        self._date_time_local_format = date_time_local_format

    @property
    def date_time_format(self):
        """
        Gets the date_time_format of this SignatureCustomAppearance.
        Gets/sets datetime format. Default value: \"yyyy.MM.dd HH:mm:ss\".

        :return: The date_time_format of this SignatureCustomAppearance.
        :rtype: str
        """
        return self._date_time_format

    @date_time_format.setter
    def date_time_format(self, date_time_format):
        """
        Sets the date_time_format of this SignatureCustomAppearance.
        Gets/sets datetime format. Default value: \"yyyy.MM.dd HH:mm:ss\".

        :param date_time_format: The date_time_format of this SignatureCustomAppearance.
        :type: str
        """

        self._date_time_format = date_time_format

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SignatureCustomAppearance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *
url = 'http://google.com'
result_name = 'fromWeb.pdf'

opts = {
    "dst_folder": temp_folder
}
response =pdf_api.put_web_in_storage_to_pdf(
    result_name, url, **opts)

pprint(response)


from configuration import *

file_name = 'PdfWithScreenAnnotations.pdf'
uploadFile(file_name)
response_annotations =pdf_api.get_document_screen_annotations(file_name, folder=temp_folder)
annotation_id = response_annotations.annotations.list[0].id
response = pdf_api.put_screen_annotation_data_extract(
    file_name, annotation_id, folder=temp_folder)

pprint(response)



import asposepdfcloud
from asposepdfcloud.apis.pdf_api import PdfApi
from asposepdfcloud.rest import ApiException
 
from  pprint import pprint

pdf_api_client = asposepdfcloud.api_client.ApiClient("b125f13bf6b76ed81ee990142d841195",
        "78946fb4-3bd4-4d3e-b309-f9e2ff9ac6f9")

temp_folder = ''
test_data_path=''
pdf_api = PdfApi(pdf_api_client)


def uploadFile(name):
        pdf_api.put_create(temp_folder + '/' + name, test_data_path + name)


# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class LettersPositioningMethods(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    USEEMUNITSANDCOMPENSATIONOFROUNDINGERRORSINCSS = "UseEmUnitsAndCompensationOfRoundingErrorsInCss"
    USEPIXELUNITSINCSSLETTERSPACINGFORIE = "UsePixelUnitsInCssLetterSpacingForIE"

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        
    }

    attribute_map = {
        
    }

    def __init__(self):
        """
        LettersPositioningMethods - a model defined in Swagger
        """



    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LettersPositioningMethods):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *
file_name = 'PdfWithEmbeddedFiles.pdf'
uploadFile(file_name)

attachment_index = 1
opts = {
    "folder": temp_folder
}

response = pdf_api.get_document_attachment_by_index(
    file_name, attachment_index, **opts)

pprint(response)



from configuration import *

file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

page_number = 2

response = pdf_api.delete_page_annotations(file_name, page_number, folder=temp_folder)
pprint(response)


# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class Paragraph(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'line_spacing': 'LineSpacing',
        'wrap_mode': 'WrapMode',
        'horizontal_alignment': 'TextHorizontalAlignment',
        'left_margin': 'float',
        'right_margin': 'float',
        'top_margin': 'float',
        'bottom_margin': 'float',
        'rectangle': 'Rectangle',
        'rotation': 'float',
        'subsequent_lines_indent': 'float',
        'vertical_alignment': 'VerticalAlignment',
        'lines': 'list[TextLine]'
    }

    attribute_map = {
        'line_spacing': 'LineSpacing',
        'wrap_mode': 'WrapMode',
        'horizontal_alignment': 'HorizontalAlignment',
        'left_margin': 'LeftMargin',
        'right_margin': 'RightMargin',
        'top_margin': 'TopMargin',
        'bottom_margin': 'BottomMargin',
        'rectangle': 'Rectangle',
        'rotation': 'Rotation',
        'subsequent_lines_indent': 'SubsequentLinesIndent',
        'vertical_alignment': 'VerticalAlignment',
        'lines': 'Lines'
    }

    def __init__(self, line_spacing=None, wrap_mode=None, horizontal_alignment=None, left_margin=None, right_margin=None, top_margin=None, bottom_margin=None, rectangle=None, rotation=None, subsequent_lines_indent=None, vertical_alignment=None, lines=None):
        """
        Paragraph - a model defined in Swagger
        """

        self._line_spacing = None
        self._wrap_mode = None
        self._horizontal_alignment = None
        self._left_margin = None
        self._right_margin = None
        self._top_margin = None
        self._bottom_margin = None
        self._rectangle = None
        self._rotation = None
        self._subsequent_lines_indent = None
        self._vertical_alignment = None
        self._lines = None

        if line_spacing is not None:
          self.line_spacing = line_spacing
        if wrap_mode is not None:
          self.wrap_mode = wrap_mode
        if horizontal_alignment is not None:
          self.horizontal_alignment = horizontal_alignment
        if left_margin is not None:
          self.left_margin = left_margin
        if right_margin is not None:
          self.right_margin = right_margin
        if top_margin is not None:
          self.top_margin = top_margin
        if bottom_margin is not None:
          self.bottom_margin = bottom_margin
        if rectangle is not None:
          self.rectangle = rectangle
        if rotation is not None:
          self.rotation = rotation
        if subsequent_lines_indent is not None:
          self.subsequent_lines_indent = subsequent_lines_indent
        if vertical_alignment is not None:
          self.vertical_alignment = vertical_alignment
        self.lines = lines

    @property
    def line_spacing(self):
        """
        Gets the line_spacing of this Paragraph.
        Line spacing mode.

        :return: The line_spacing of this Paragraph.
        :rtype: LineSpacing
        """
        return self._line_spacing

    @line_spacing.setter
    def line_spacing(self, line_spacing):
        """
        Sets the line_spacing of this Paragraph.
        Line spacing mode.

        :param line_spacing: The line_spacing of this Paragraph.
        :type: LineSpacing
        """

        self._line_spacing = line_spacing

    @property
    def wrap_mode(self):
        """
        Gets the wrap_mode of this Paragraph.
        Word wrap mode.

        :return: The wrap_mode of this Paragraph.
        :rtype: WrapMode
        """
        return self._wrap_mode

    @wrap_mode.setter
    def wrap_mode(self, wrap_mode):
        """
        Sets the wrap_mode of this Paragraph.
        Word wrap mode.

        :param wrap_mode: The wrap_mode of this Paragraph.
        :type: WrapMode
        """

        self._wrap_mode = wrap_mode

    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment of this Paragraph.
        Horizontal alignment for the text inside paragraph's rectangle.

        :return: The horizontal_alignment of this Paragraph.
        :rtype: TextHorizontalAlignment
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment of this Paragraph.
        Horizontal alignment for the text inside paragraph's rectangle.

        :param horizontal_alignment: The horizontal_alignment of this Paragraph.
        :type: TextHorizontalAlignment
        """

        self._horizontal_alignment = horizontal_alignment

    @property
    def left_margin(self):
        """
        Gets the left_margin of this Paragraph.
        Left margin.

        :return: The left_margin of this Paragraph.
        :rtype: float
        """
        return self._left_margin

    @left_margin.setter
    def left_margin(self, left_margin):
        """
        Sets the left_margin of this Paragraph.
        Left margin.

        :param left_margin: The left_margin of this Paragraph.
        :type: float
        """

        self._left_margin = left_margin

    @property
    def right_margin(self):
        """
        Gets the right_margin of this Paragraph.
        Right margin.

        :return: The right_margin of this Paragraph.
        :rtype: float
        """
        return self._right_margin

    @right_margin.setter
    def right_margin(self, right_margin):
        """
        Sets the right_margin of this Paragraph.
        Right margin.

        :param right_margin: The right_margin of this Paragraph.
        :type: float
        """

        self._right_margin = right_margin

    @property
    def top_margin(self):
        """
        Gets the top_margin of this Paragraph.
        Top margin.

        :return: The top_margin of this Paragraph.
        :rtype: float
        """
        return self._top_margin

    @top_margin.setter
    def top_margin(self, top_margin):
        """
        Sets the top_margin of this Paragraph.
        Top margin.

        :param top_margin: The top_margin of this Paragraph.
        :type: float
        """

        self._top_margin = top_margin

    @property
    def bottom_margin(self):
        """
        Gets the bottom_margin of this Paragraph.
        Bottom margin.

        :return: The bottom_margin of this Paragraph.
        :rtype: float
        """
        return self._bottom_margin

    @bottom_margin.setter
    def bottom_margin(self, bottom_margin):
        """
        Sets the bottom_margin of this Paragraph.
        Bottom margin.

        :param bottom_margin: The bottom_margin of this Paragraph.
        :type: float
        """

        self._bottom_margin = bottom_margin

    @property
    def rectangle(self):
        """
        Gets the rectangle of this Paragraph.
        Rectangle of the paragraph.

        :return: The rectangle of this Paragraph.
        :rtype: Rectangle
        """
        return self._rectangle

    @rectangle.setter
    def rectangle(self, rectangle):
        """
        Sets the rectangle of this Paragraph.
        Rectangle of the paragraph.

        :param rectangle: The rectangle of this Paragraph.
        :type: Rectangle
        """

        self._rectangle = rectangle

    @property
    def rotation(self):
        """
        Gets the rotation of this Paragraph.
        Rotation angle in degrees.

        :return: The rotation of this Paragraph.
        :rtype: float
        """
        return self._rotation

    @rotation.setter
    def rotation(self, rotation):
        """
        Sets the rotation of this Paragraph.
        Rotation angle in degrees.

        :param rotation: The rotation of this Paragraph.
        :type: float
        """

        self._rotation = rotation

    @property
    def subsequent_lines_indent(self):
        """
        Gets the subsequent_lines_indent of this Paragraph.
        Subsequent lines indent value.

        :return: The subsequent_lines_indent of this Paragraph.
        :rtype: float
        """
        return self._subsequent_lines_indent

    @subsequent_lines_indent.setter
    def subsequent_lines_indent(self, subsequent_lines_indent):
        """
        Sets the subsequent_lines_indent of this Paragraph.
        Subsequent lines indent value.

        :param subsequent_lines_indent: The subsequent_lines_indent of this Paragraph.
        :type: float
        """

        self._subsequent_lines_indent = subsequent_lines_indent

    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment of this Paragraph.
        Vertical alignment for the text inside paragraph's rectangle

        :return: The vertical_alignment of this Paragraph.
        :rtype: VerticalAlignment
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment of this Paragraph.
        Vertical alignment for the text inside paragraph's rectangle

        :param vertical_alignment: The vertical_alignment of this Paragraph.
        :type: VerticalAlignment
        """

        self._vertical_alignment = vertical_alignment

    @property
    def lines(self):
        """
        Gets the lines of this Paragraph.
        An array of text lines.

        :return: The lines of this Paragraph.
        :rtype: list[TextLine]
        """
        return self._lines

    @lines.setter
    def lines(self, lines):
        """
        Sets the lines of this Paragraph.
        An array of text lines.

        :param lines: The lines of this Paragraph.
        :type: list[TextLine]
        """
        if lines is None:
            raise ValueError("Invalid value for `lines`, must not be `None`")

        self._lines = lines

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Paragraph):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


from pprint import pformat
from six import iteritems
import re


class Table(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'links': 'list[Link]',
        'alignment': 'HorizontalAlignment',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'top': 'float',
        'left': 'float',
        'default_cell_text_state': 'TextState',
        'default_cell_padding': 'MarginInfo',
        'border': 'BorderInfo',
        'margin': 'MarginInfo',
        'rows': 'list[Row]',
        'default_column_width': 'str',
        'default_cell_border': 'BorderInfo',
        'broken': 'TableBroken',
        'column_widths': 'str',
        'repeating_rows_count': 'int',
        'repeating_columns_count': 'int',
        'repeating_rows_style': 'TextState',
        'corner_style': 'BorderCornerStyle',
        'break_text': 'TextRect',
        'background_color': 'Color',
        'is_borders_included': 'bool',
        'column_adjustment': 'ColumnAdjustment',
        'z_index': 'int'
    }

    attribute_map = {
        'links': 'Links',
        'alignment': 'Alignment',
        'horizontal_alignment': 'HorizontalAlignment',
        'vertical_alignment': 'VerticalAlignment',
        'top': 'Top',
        'left': 'Left',
        'default_cell_text_state': 'DefaultCellTextState',
        'default_cell_padding': 'DefaultCellPadding',
        'border': 'Border',
        'margin': 'Margin',
        'rows': 'Rows',
        'default_column_width': 'DefaultColumnWidth',
        'default_cell_border': 'DefaultCellBorder',
        'broken': 'Broken',
        'column_widths': 'ColumnWidths',
        'repeating_rows_count': 'RepeatingRowsCount',
        'repeating_columns_count': 'RepeatingColumnsCount',
        'repeating_rows_style': 'RepeatingRowsStyle',
        'corner_style': 'CornerStyle',
        'break_text': 'BreakText',
        'background_color': 'BackgroundColor',
        'is_borders_included': 'IsBordersIncluded',
        'column_adjustment': 'ColumnAdjustment',
        'z_index': 'ZIndex'
    }

    def __init__(self, links=None, alignment=None, horizontal_alignment=None, vertical_alignment=None, top=None, left=None, default_cell_text_state=None, default_cell_padding=None, border=None, margin=None, rows=None, default_column_width=None, default_cell_border=None, broken=None, column_widths=None, repeating_rows_count=None, repeating_columns_count=None, repeating_rows_style=None, corner_style=None, break_text=None, background_color=None, is_borders_included=None, column_adjustment=None, z_index=None):
        """
        Table - a model defined in Swagger
        """

        self._links = None
        self._alignment = None
        self._horizontal_alignment = None
        self._vertical_alignment = None
        self._top = None
        self._left = None
        self._default_cell_text_state = None
        self._default_cell_padding = None
        self._border = None
        self._margin = None
        self._rows = None
        self._default_column_width = None
        self._default_cell_border = None
        self._broken = None
        self._column_widths = None
        self._repeating_rows_count = None
        self._repeating_columns_count = None
        self._repeating_rows_style = None
        self._corner_style = None
        self._break_text = None
        self._background_color = None
        self._is_borders_included = None
        self._column_adjustment = None
        self._z_index = None

        if links is not None:
          self.links = links
        if alignment is not None:
          self.alignment = alignment
        if horizontal_alignment is not None:
          self.horizontal_alignment = horizontal_alignment
        if vertical_alignment is not None:
          self.vertical_alignment = vertical_alignment
        if top is not None:
          self.top = top
        if left is not None:
          self.left = left
        if default_cell_text_state is not None:
          self.default_cell_text_state = default_cell_text_state
        if default_cell_padding is not None:
          self.default_cell_padding = default_cell_padding
        if border is not None:
          self.border = border
        if margin is not None:
          self.margin = margin
        self.rows = rows
        if default_column_width is not None:
          self.default_column_width = default_column_width
        if default_cell_border is not None:
          self.default_cell_border = default_cell_border
        if broken is not None:
          self.broken = broken
        if column_widths is not None:
          self.column_widths = column_widths
        if repeating_rows_count is not None:
          self.repeating_rows_count = repeating_rows_count
        if repeating_columns_count is not None:
          self.repeating_columns_count = repeating_columns_count
        if repeating_rows_style is not None:
          self.repeating_rows_style = repeating_rows_style
        if corner_style is not None:
          self.corner_style = corner_style
        if break_text is not None:
          self.break_text = break_text
        if background_color is not None:
          self.background_color = background_color
        if is_borders_included is not None:
          self.is_borders_included = is_borders_included
        if column_adjustment is not None:
          self.column_adjustment = column_adjustment
        if z_index is not None:
          self.z_index = z_index

    @property
    def links(self):
        """
        Gets the links of this Table.
        Link to the document.

        :return: The links of this Table.
        :rtype: list[Link]
        """
        return self._links

    @links.setter
    def links(self, links):
        """
        Sets the links of this Table.
        Link to the document.

        :param links: The links of this Table.
        :type: list[Link]
        """

        self._links = links

    @property
    def alignment(self):
        """
        Gets the alignment of this Table.
        Gets HorizontalAlignment of the table alignment.

        :return: The alignment of this Table.
        :rtype: HorizontalAlignment
        """
        return self._alignment

    @alignment.setter
    def alignment(self, alignment):
        """
        Sets the alignment of this Table.
        Gets HorizontalAlignment of the table alignment.

        :param alignment: The alignment of this Table.
        :type: HorizontalAlignment
        """

        self._alignment = alignment

    @property
    def horizontal_alignment(self):
        """
        Gets the horizontal_alignment of this Table.
        Gets HorizontalAlignment of the table alignment.

        :return: The horizontal_alignment of this Table.
        :rtype: HorizontalAlignment
        """
        return self._horizontal_alignment

    @horizontal_alignment.setter
    def horizontal_alignment(self, horizontal_alignment):
        """
        Sets the horizontal_alignment of this Table.
        Gets HorizontalAlignment of the table alignment.

        :param horizontal_alignment: The horizontal_alignment of this Table.
        :type: HorizontalAlignment
        """

        self._horizontal_alignment = horizontal_alignment

    @property
    def vertical_alignment(self):
        """
        Gets the vertical_alignment of this Table.
        Gets VerticalAlignment of the annotation.

        :return: The vertical_alignment of this Table.
        :rtype: VerticalAlignment
        """
        return self._vertical_alignment

    @vertical_alignment.setter
    def vertical_alignment(self, vertical_alignment):
        """
        Sets the vertical_alignment of this Table.
        Gets VerticalAlignment of the annotation.

        :param vertical_alignment: The vertical_alignment of this Table.
        :type: VerticalAlignment
        """

        self._vertical_alignment = vertical_alignment

    @property
    def top(self):
        """
        Gets the top of this Table.
        Gets or sets the table top coordinate.

        :return: The top of this Table.
        :rtype: float
        """
        return self._top

    @top.setter
    def top(self, top):
        """
        Sets the top of this Table.
        Gets or sets the table top coordinate.

        :param top: The top of this Table.
        :type: float
        """

        self._top = top

    @property
    def left(self):
        """
        Gets the left of this Table.
        Gets or sets the table left coordinate.

        :return: The left of this Table.
        :rtype: float
        """
        return self._left

    @left.setter
    def left(self, left):
        """
        Sets the left of this Table.
        Gets or sets the table left coordinate.

        :param left: The left of this Table.
        :type: float
        """

        self._left = left

    @property
    def default_cell_text_state(self):
        """
        Gets the default_cell_text_state of this Table.
        Gets or sets the default cell text state.

        :return: The default_cell_text_state of this Table.
        :rtype: TextState
        """
        return self._default_cell_text_state

    @default_cell_text_state.setter
    def default_cell_text_state(self, default_cell_text_state):
        """
        Sets the default_cell_text_state of this Table.
        Gets or sets the default cell text state.

        :param default_cell_text_state: The default_cell_text_state of this Table.
        :type: TextState
        """

        self._default_cell_text_state = default_cell_text_state

    @property
    def default_cell_padding(self):
        """
        Gets the default_cell_padding of this Table.
        Gets or sets the default cell padding.

        :return: The default_cell_padding of this Table.
        :rtype: MarginInfo
        """
        return self._default_cell_padding

    @default_cell_padding.setter
    def default_cell_padding(self, default_cell_padding):
        """
        Sets the default_cell_padding of this Table.
        Gets or sets the default cell padding.

        :param default_cell_padding: The default_cell_padding of this Table.
        :type: MarginInfo
        """

        self._default_cell_padding = default_cell_padding

    @property
    def border(self):
        """
        Gets the border of this Table.
        Gets or sets the border.

        :return: The border of this Table.
        :rtype: BorderInfo
        """
        return self._border

    @border.setter
    def border(self, border):
        """
        Sets the border of this Table.
        Gets or sets the border.

        :param border: The border of this Table.
        :type: BorderInfo
        """

        self._border = border

    @property
    def margin(self):
        """
        Gets the margin of this Table.
        Gets or sets a outer margin for paragraph (for pdf generation)

        :return: The margin of this Table.
        :rtype: MarginInfo
        """
        return self._margin

    @margin.setter
    def margin(self, margin):
        """
        Sets the margin of this Table.
        Gets or sets a outer margin for paragraph (for pdf generation)

        :param margin: The margin of this Table.
        :type: MarginInfo
        """

        self._margin = margin

    @property
    def rows(self):
        """
        Gets the rows of this Table.
        Sets the rows of the table.

        :return: The rows of this Table.
        :rtype: list[Row]
        """
        return self._rows

    @rows.setter
    def rows(self, rows):
        """
        Sets the rows of this Table.
        Sets the rows of the table.

        :param rows: The rows of this Table.
        :type: list[Row]
        """
        if rows is None:
            raise ValueError("Invalid value for `rows`, must not be `None`")

        self._rows = rows

    @property
    def default_column_width(self):
        """
        Gets the default_column_width of this Table.
        Gets default cell border;

        :return: The default_column_width of this Table.
        :rtype: str
        """
        return self._default_column_width

    @default_column_width.setter
    def default_column_width(self, default_column_width):
        """
        Sets the default_column_width of this Table.
        Gets default cell border;

        :param default_column_width: The default_column_width of this Table.
        :type: str
        """

        self._default_column_width = default_column_width

    @property
    def default_cell_border(self):
        """
        Gets the default_cell_border of this Table.
        Gets default cell border;

        :return: The default_cell_border of this Table.
        :rtype: BorderInfo
        """
        return self._default_cell_border

    @default_cell_border.setter
    def default_cell_border(self, default_cell_border):
        """
        Sets the default_cell_border of this Table.
        Gets default cell border;

        :param default_cell_border: The default_cell_border of this Table.
        :type: BorderInfo
        """

        self._default_cell_border = default_cell_border

    @property
    def broken(self):
        """
        Gets the broken of this Table.
        Gets or sets table vertial broken;

        :return: The broken of this Table.
        :rtype: TableBroken
        """
        return self._broken

    @broken.setter
    def broken(self, broken):
        """
        Sets the broken of this Table.
        Gets or sets table vertial broken;

        :param broken: The broken of this Table.
        :type: TableBroken
        """

        self._broken = broken

    @property
    def column_widths(self):
        """
        Gets the column_widths of this Table.
        Gets the column widths of the table.

        :return: The column_widths of this Table.
        :rtype: str
        """
        return self._column_widths

    @column_widths.setter
    def column_widths(self, column_widths):
        """
        Sets the column_widths of this Table.
        Gets the column widths of the table.

        :param column_widths: The column_widths of this Table.
        :type: str
        """

        self._column_widths = column_widths

    @property
    def repeating_rows_count(self):
        """
        Gets the repeating_rows_count of this Table.
        Gets the first rows count repeated for several pages

        :return: The repeating_rows_count of this Table.
        :rtype: int
        """
        return self._repeating_rows_count

    @repeating_rows_count.setter
    def repeating_rows_count(self, repeating_rows_count):
        """
        Sets the repeating_rows_count of this Table.
        Gets the first rows count repeated for several pages

        :param repeating_rows_count: The repeating_rows_count of this Table.
        :type: int
        """

        self._repeating_rows_count = repeating_rows_count

    @property
    def repeating_columns_count(self):
        """
        Gets the repeating_columns_count of this Table.
        Gets or sets the maximum columns count for table

        :return: The repeating_columns_count of this Table.
        :rtype: int
        """
        return self._repeating_columns_count

    @repeating_columns_count.setter
    def repeating_columns_count(self, repeating_columns_count):
        """
        Sets the repeating_columns_count of this Table.
        Gets or sets the maximum columns count for table

        :param repeating_columns_count: The repeating_columns_count of this Table.
        :type: int
        """

        self._repeating_columns_count = repeating_columns_count

    @property
    def repeating_rows_style(self):
        """
        Gets the repeating_rows_style of this Table.
        Gets the style for repeating rows

        :return: The repeating_rows_style of this Table.
        :rtype: TextState
        """
        return self._repeating_rows_style

    @repeating_rows_style.setter
    def repeating_rows_style(self, repeating_rows_style):
        """
        Sets the repeating_rows_style of this Table.
        Gets the style for repeating rows

        :param repeating_rows_style: The repeating_rows_style of this Table.
        :type: TextState
        """

        self._repeating_rows_style = repeating_rows_style

    @property
    def corner_style(self):
        """
        Gets the corner_style of this Table.
        Gets or sets the styles of the border corners

        :return: The corner_style of this Table.
        :rtype: BorderCornerStyle
        """
        return self._corner_style

    @corner_style.setter
    def corner_style(self, corner_style):
        """
        Sets the corner_style of this Table.
        Gets or sets the styles of the border corners

        :param corner_style: The corner_style of this Table.
        :type: BorderCornerStyle
        """

        self._corner_style = corner_style

    @property
    def break_text(self):
        """
        Gets the break_text of this Table.
        Gets or sets break text for table

        :return: The break_text of this Table.
        :rtype: TextRect
        """
        return self._break_text

    @break_text.setter
    def break_text(self, break_text):
        """
        Sets the break_text of this Table.
        Gets or sets break text for table

        :param break_text: The break_text of this Table.
        :type: TextRect
        """

        self._break_text = break_text

    @property
    def background_color(self):
        """
        Gets the background_color of this Table.
        Gets or sets table background color

        :return: The background_color of this Table.
        :rtype: Color
        """
        return self._background_color

    @background_color.setter
    def background_color(self, background_color):
        """
        Sets the background_color of this Table.
        Gets or sets table background color

        :param background_color: The background_color of this Table.
        :type: Color
        """

        self._background_color = background_color

    @property
    def is_borders_included(self):
        """
        Gets the is_borders_included of this Table.
        Gets or sets border included in column widhts.

        :return: The is_borders_included of this Table.
        :rtype: bool
        """
        return self._is_borders_included

    @is_borders_included.setter
    def is_borders_included(self, is_borders_included):
        """
        Sets the is_borders_included of this Table.
        Gets or sets border included in column widhts.

        :param is_borders_included: The is_borders_included of this Table.
        :type: bool
        """

        self._is_borders_included = is_borders_included

    @property
    def column_adjustment(self):
        """
        Gets the column_adjustment of this Table.
        Gets or sets the table column adjustment.

        :return: The column_adjustment of this Table.
        :rtype: ColumnAdjustment
        """
        return self._column_adjustment

    @column_adjustment.setter
    def column_adjustment(self, column_adjustment):
        """
        Sets the column_adjustment of this Table.
        Gets or sets the table column adjustment.

        :param column_adjustment: The column_adjustment of this Table.
        :type: ColumnAdjustment
        """

        self._column_adjustment = column_adjustment

    @property
    def z_index(self):
        """
        Gets the z_index of this Table.
        Gets ZIndex of the annotation.

        :return: The z_index of this Table.
        :rtype: int
        """
        return self._z_index

    @z_index.setter
    def z_index(self, z_index):
        """
        Sets the z_index of this Table.
        Gets ZIndex of the annotation.

        :param z_index: The z_index of this Table.
        :type: int
        """

        self._z_index = z_index

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Table):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



from configuration import *
file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

response = pdf_api.get_document_file_attachment_annotations(
    file_name, folder=temp_folder)
pprint(response)


from configuration import *

file_name = 'PdfWithAnnotations.pdf'
uploadFile(file_name)

page_number = 2

response = pdf_api.get_page_stamp_annotations(
    file_name, page_number, folder=temp_folder)

pprint(response)



from configuration import *
file_name = 'PdfWithImages2.pdf'
append_file_name = '4pages.pdf'

uploadFile(file_name)
uploadFile(append_file_name)

opts = {
    "append_file": temp_folder + '/' + append_file_name,
    "start_page": 2,
    "end_page": 4,
    "folder": temp_folder
}

response = pdf_api.post_append_document(file_name, **opts)
pprint(response)


# coding: utf-8

"""
    Aspose.PDF Cloud API Reference


Copyright (c) 2023 Aspose.PDF Cloud
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:
The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.
THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.



    OpenAPI spec version: 3.0
    
"""


import sys
from setuptools import setup, find_packages

NAME = "asposepdfcloud"
VERSION = "23.1.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi >= 14.05.14", "python-dateutil >= 2.5.3", "setuptools >= 21.0.0"]

setup(
    name=NAME,
    version=VERSION,
    description="Aspose.PDF Cloud",
    long_description='''Aspose.PDF Cloud is a REST API for creating and editing PDF files.
 Most popular features proposed by Aspose.PDF Cloud: PDF to Word, Convert PDF to Image, Merge PDF, Split PDF, Add Images to PDF, Rotate PDF.
 It can also be used to convert PDF files to different formats like DOC, HTML, XPS, TIFF and many more.
 Aspose.PDF Cloud gives you control: create PDFs from scratch or from HTML, XML, template, database, XPS or an image.
 Render PDFs to image formats such as JPEG, PNG, GIF, BMP, TIFF and many others.
 Aspose.PDF Cloud helps you manipulate elements of a PDF file like text, annotations, watermarks, signatures, bookmarks, stamps and so on.
 Its REST API also allows you to manage PDF pages by using features like merging, splitting, and inserting.
 Add images to a PDF file or convert PDF pages to images.''',
    author_email="",
    url="https://products.aspose.cloud/pdf/cloud",
    author='Aspose PDF Cloud',
    license='MIT',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
    ],
    keywords=[        "Aspose",
        "Cloud",
        "PDF",
        "Aspose.PDF",
        "Aspose.PDF-Cloud",
        "Aspose.Total-Cloud",
        "REST",
        "API",
        "EPUB",
        "HTML",
        "TEX",
        "MHT",
        "PCL",
        "PS",
        "PostScript",
        "SVG",
        "XML",
        "XPS",
        "XSLFO",
        "MD",
        "Markdown",
        "XLS",
        "XLSX",
        "PPTX",
        "DOC",
        "DOCX",
        "EPUB",
        "HTML",
        "MobiXML",
        "SVG",
        "JPEG",
        "EMF",
        "PNG",
        "BMP",
        "GIF",
        "TIFF",
        "XML",
        "XPS",
        "Text",
        "FDF",
        "XFDF",
        "PDFA3",
        "PDF-to-DOC",
        "PDF-to-DOCX",
        "PDF-to-HTML",
        "PDF-to-PDFA",
        "PDF-to-TIFF",
        "PDF-to-SVG",
        "PDF-to-EPUB",
        "PDF-to-PPTX",
        "PDF-to-TEX",
        "PDF-to-MobiXML",
        "PDF-to-XFA",
        "PDF-to-XML",
        "PDF-to-XPS",
        "PDF-to-XLS",
        "EPUB-to-PDF",
        "Web-to-PDF",
        "TEX-to-PDF",
        "MHT-to-PDF",
        "HTML-to-PDF",
        "PS-to-PDF",
        "PostScript-to-PDF",
        "XSIF-to-PDF",
        "XPS-to-PDF",
        "SVG-to-PDF",
        "DOC-to-PDF",
        "DOCX-to-PDF",
        "PCL-to-PDF",
        "XML-to-PDF",
        "Markdown-to-PDF",
        "MD-to-PDF",
        "Annotation",
        "Line-Annotation",
        "Circle-Annotation",
        "Square-Annotation",
        "Underline-Annotation",
        "Squiggly-Annotation",
        "PDF-Bookmark",
        "PDF-Link",
        "PDF-Attachment",
        "PDF-Document",
        "PDF-Page",
        "PDF-Form-Fields",
        "PDF-Text",
        "PDF-Image",
        "Replace-Text",
        "Fetch-Text",
        "Replace-Image",
        "Extract-Image",
        "Convert-PDF",
        "Convert",
        "Converter",
        "PDF-to-Image",
        "Create-PDF",
        "Convert-PDF",
        "Stamp",
        "PDF-OCR",
        "OCR-Layers",
        ".NET",
        "C#",
        "dotnet",
        "CSharp"
    ],
    install_requires=REQUIRES,
    extras_require={ 
        'test': ["requests >= 2.18.4",
                "coverage >= 4.0.3",
                "nose >= 1.3.7",
                "pluggy >= 0.3.1",
                "py >= 1.4.31",
                "randomize >= 0.13"],
    },
    packages=find_packages(exclude=['test']),
    project_urls={ 
        'Source With Tests': 'https://github.com/aspose-pdf-cloud/aspose-pdf-cloud-python',
        'Website': 'https://www.aspose.cloud',
        'Product Home': 'https://products.aspose.cloud/pdf/cloud',
        'Documentation': 'https://docs.aspose.cloud/display/pdfcloud/Home',
        'Free Support Forum': 'https://forum.aspose.cloud/c/pdf',
        'Paid Support Helpdesk': 'https://helpdesk.aspose.cloud/',
        'Blog': 'https://blog.aspose.cloud/category/aspose-products/aspose-pdf-product-family/',
    },
)
